;; cursus.el

;; David Chadd <d.chadd@uea.ac.uk> <cursus@uea.ac.uk>

;; A file of emacs-lisp code to assist with editing the TEI-encoded
;; files of the CURSUS project <http://www.cursus.uea.ac.uk/>.

;; NBB: THIS FILE IS WORK-IN-PROGRESS.
;; Original file creation: 19 October 2000
;; The current version is 1.0.1: 30 September 2003 (first public
;; version)

;; This file is free software; you can redistribute it and/or modify
;; it under the terms of the GNU General Public License as published
;; by the Free Software Foundation; either version 2, or (at your
;; option) any later version.
;;
;; cursus.el is distributed in the hope that it will be useful, but
;; WITHOUT ANY WARRANTY; without even the implied warranty of
;; MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
;; General Public License for more details.
;;
;; You should have received a copy of the GNU General Public License
;; along with GNU Emacs; see the file COPYING.  If not, write to the
;; Free Software Foundation, 675 Mass Ave, Cambridge, MA 02139, USA.

;; Put this file somewhere in your loadpath and add this to your
;; .emacs file (removing the ';;' comment string):
;; (require 'cursus)
;; 
;; This file is categorised by markers for the Emacs folding mode.
;; Folding mode can reportedly cause problems under Windows.  In this
;; case, do
;;               M-x occur ;;{{{ [RETURN]
;; which will effectively give you a right-clickable Table of Contents
;; in a second buffer.
;; 
;; The code in this file requires you to be using Lennart Stafflin's
;; psgml mode.  You will also need to have loaded the Common Lisp
;; extensions of the 'CL' package.
;; ------------------------------------------------------------------------------

;;{{{ User customisation:

(defgroup cursus nil
  "Routines for editing Cursus project xml files."
  :group 'editing)

(defcustom user-initials 
  "DC"
  "*The initials of the current user, e.g. the value of any @resp"
  :type 'string
  :group 'cursus)

(defcustom occ-file 
  "c:/cursus/cantus/occasions.txt"
  "*The full path to the file `occasions.txt' which contains the
day-codes and their accompanying descriptions."
  :type 'string
  :group 'cursus)

(defcustom cursus-write-logfile t
  "*If non-nil, the process of inserting the id number of a repository
item into a manuscript file after editing it will also create \(where
necessary\) and update a logfile of the editing action, in the file
named in the variable `repos-log-file'."
  :type 'boolean
  :group 'cursus)

(defcustom repos-log-file
  "c:/cursus/dflc-work/repos-log"
  "*The full path to, and name of, the file of the log of repository
editing, provided that the variable `cursus-write-logfile' is set to
non-nil."
  :type 'string
  :group 'cursus)

(defcustom cursus-sort-log nil
  "*If non-nil, the logfile recording edits to the repository file
will be sorted by the value of the @id of repository items edited.  If
nil, it will simply add successive edits to the log, which will
therefore be ordered chronologically."
  :type 'boolean
  :group 'cursus)

(defcustom sigla
  '(
    ("battle.xml" "Bat")
    ("chertsey.xml" "Cht")
    ("coldingham.xml" "Cld")
    ("ely.xml" "Ely")
    ("evesham.xml" "Evm")
    ("fecampb2.xml" "Fec-B2")
    ("gloucester.xml" "Glo")
    ("hyde.xml" "Hyd")
    ("muchelney.xml" "Mch")
    ("peterborough.xml" "Pet")
    ("stalbans.xml" "Alb2")
    ("winchcombe.xml" "Wcb")
    )
  "*An a-list of Cursus project manuscript filenames and the Ms sigla
associated with them.  
Each element is a list of two strings with the form (KEY VALUE)
where KEY is the filename of the manuscript file and VALUE is the
siglum corresponding to that manuscript.
This variable can be customised."
  :type 'alist;; :key-type (string) :value-type (string)
  :group 'cursus)

;;}}} ---------------------------------------------------------------------------

;;{{{ A-lists:

(defvar occasions
  '(
    ("01000000" "In tempore Adventus" "General, in Advent" "")
    ("01001000" "Dominicae Adventus" "Sundays in Advent" "")
    ("01002000" "Feria 2 Adventus" "Mondays in Advent" "")
    ("01003000" "Feria 3 Adventus" "Tuesdays in Advent" "")
    ("01004000" "Feria 4 Adventus" "Wednesdays in Advent" "")
    ("01008000" "Feriae Adventus" "Weekdays in Advent" "")
    ("01011000" "Dominica 1 Adventus" "1st Sunday of Advent" "")
    ("01012000" "Feria 2 Hebdomada 1 Adventus" "Monday, 1st week, Advent" "")
    ("01013000" "Feria 3 Hebdomada 1 Adventus" "Tuesday, 1st week, Advent" "")
    ("01014000" "Feria 4 Hebdomada 1 Adventus" "Wednesday, 1st week, Advent" "")
    ("01015000" "Feria 5 Hebdomada 1 Adventus" "Thursday, 1st week, Advent" "")
    ("01016000" "Feria 6 Hebdomada 1 Adventus" "Friday, 1st week, Advent" "")
    ("01017000" "Sabbato Hebdomada 1 Adventus" "Saturday, 1st week, Advent" "")
    ("01018000" "Hebdomada 1 Adventus" "1st week of Advent" "")
    ("01021000" "Dominica 2 Adventus" "2nd Sunday of Advent" "")
    ("01022000" "Feria 2 Hebdomada 2 Adventus" "Monday, 2nd week, Advent" "")
    ("01023000" "Feria 3 Hebdomada 2 Adventus" "Tuesday, 2nd week, Advent" "")
    ("01024000" "Feria 4 Hebdomada 2 Adventus" "Wednesday, 2nd week, Advent" "")
    ("01025000" "Feria 5 Hebdomada 2 Adventus" "Thursday, 2nd week, Advent" "")
    ("01026000" "Feria 6 Hebdomada 2 Adventus" "Friday, 2nd week, Advent" "")
    ("01027000" "Sabbato Hebdomada 2 Adventus" "Saturday, 2nd week, Advent" "")
    ("01028000" "Hebdomada 2 Adventus" "2nd week of Advent" "")
    ("01030009" "Quatuor Tempora Adventus" "Ember Days, Advent" "")
    ("01031000" "Dominica 3 Adventus" "3rd Sunday of Advent" "")
    ("01032000" "Feria 2 Hebdomada 3 Adventus" "Monday, 3rd week, Advent" "")
    ("01033000" "Feria 3 Hebdomada 3 Adventus" "Tuesday, 3rd week, Advent" "")
    ("01034000" "Feria 4 Hebdomada 3 Adventus" "Wednesday, 3rd week, Advent" "")
    ("01034009" "Feria 4 Quatuor Tempora Adventus" "Ember Day, Advent: Wednesday" "")
    ("01035000" "Feria 5 Hebdomada 3 Adventus" "Thursday, 3rd week, Advent" "")
    ("01035009" "Feria 5 Quatuor Tempora Adventus" "Ember Day, Advent: Thursday" "")
    ("01036000" "Feria 6 Hebdomada 3 Adventus" "Friday, 3rd week, Advent" "")
    ("01036009" "Feria 6 Quatuor Tempora Adventus" "Ember Day, Advent: Friday" "")
    ("01037000" "Sabbato Hebdomada 3 Adventus" "Saturday, 3rd week, Advent" "")
    ("01037009" "Sabbato Quatuor Tempora Adventus" "Ember Day, Advent: Saturday" "")
    ("01038000" "Hebdomada 3 Adventus" "3rd week of Advent" "")
    ("01041000" "Dominica 4 Adventus" "4th Sunday of Advent" "")
    ("01042000" "Feria 2 Hebdomada 4 Adventus" "Monday, 4th week, Advent" "")
    ("01043000" "Feria 3 Hebdomada 4 Adventus" "Tuesday, 4th week, Advent" "")
    ("01044000" "Feria 4 Hebdomada 4 Adventus" "Wednesday, 4th week, Advent" "")
    ("01045000" "Feria 5 Hebdomada 4 Adventus" "Thursday, 4th week, Advent" "")
    ("01046000" "Feria 6 Hebdomada 4 Adventus" "Friday, 4th week, Advent" "")
    ("01047000" "Sabbato Hebdomada 4 Adventus" "Saturday, 4th week, Advent" "")
    ("01048000" "Hebdomada 4 Adventus" "4th week of Advent" "")
    ("01048010" "Antiphonae Maiores" "Great 'O' Antiphons" "")
    ("02010100" "Octava Nativitatis Domini" "Octave of Christmas: Circumcision" "")
    ("02010108" "Octava Nativitatis Domini, 8" "In week after Octave of Christmas" "")
    ("02010200" "Octava S. Stephani" "Octave of Stephen" "")
    ("02010300" "Octava S. Joannis Ev." "Octave of John the Evangelist" "")
    ("02010400" "Octava Innocentium" "Octave of Holy Innocents" "")
    ("02010500" "Vigilia Epiphaniae" "Eve of Epiphany" "")
    ("02010600" "Epiphania" "Epiphany" "")
    ("02010608" "In Octava Epiphaniae" "In week after Epiphany" "")
    ("02010700" "Die 2 post Epiphaniam" "1st day after Epiphany" "")
    ("02010800" "Die 3 post Epiphaniam" "2nd day after Epiphany" "")
    ("02010900" "Die 4 post Epiphaniam" "3rd day after Epiphany" "")
    ("02011000" "Die 5 post Epiphaniam" "4th day after Epiphany" "")
    ("02011100" "Die 6 post Epiphaniam" "5th day after Epiphany" "")
    ("02011200" "Die 7 post Epiphaniam" "6th day after Epiphany" "")
    ("02011300" "Octava Epiphaniae" "Octave of Epiphany" "")
    ("02122400" "Vigilia Nativitatis Domini" "Christmas Eve" "")
    ("02122500" "Nativitas Domini" "Christmas Day" "")
    ("02122508" "Nativitas Domini, infra octavas" "In week after Christmas" "")
    ("02122600" "S. Stephani" "Stephen the First Martyr" "")
    ("02122608" "S. Stephani, infra octavas" "In week after Stephen" "")
    ("02122700" "S. Joannis Evang." "John the Evangelist" "")
    ("02122708" "Infra Octavas S. Joannis Evang." "In week after John the Evangelist" "")
    ("02122800" "Nativitas Innocentium" "Holy Innocents" "")
    ("02122808" "Nativitas Innocentium, 8" "In week after Holy Innocents" "")
    ("02122900" "Die 5 post Nativitatem Domini" "4th day after Christmas" "")
    ("02123000" "Die 6 post Nativitatem Domini" "5th day after Christmas" "")
    ("02123100" "Die 7 post Nativitatem Domini" "6th day after Christmas" "")
    ("03000000" "In tempore Nativitatis" "General, in Christmastide" "")
    ("03021000" "Dominica post Nativitatem Domini" "Sunday after Christmas" "")
    ("03022000" "Feria 2 post Nativitatem Domini" "Monday, week after Christmas" "")
    ("03023000" "Feria 3 post Nativitatem Domini" "Tuesday, week after Christmas" "")
    ("03024000" "Feria 4 post Nativitatem Domini" "Wednesday, week after Christmas" "")
    ("03025000" "Feria 5 post Nativitatem Domini" "Thursday, week after Christmas" "")
    ("03026000" "Feria 6 post Nativitatem Domini" "Friday, week after Christmas" "")
    ("03027000" "Sabbato post Nativitatem Domini" "Saturday after Christmas" "")
    ("03031000" "Dominica post Octavas Nativitatis" "Sunday after Octave of Christmas" "")
    ("04001000" "Dominicae per annum" "Sundays, Ferial Office" "")
    ("04002000" "Feria 2 per annum" "Mondays, Ferial Office" "")
    ("04003000" "Feria 3 per annum" "Tuesdays, Ferial Office" "")
    ("04004000" "Feria 4 per annum" "Wednesdays, Ferial Office" "")
    ("04005000" "Feria 5 per annum" "Thursdays, Ferial Office" "")
    ("04006000" "Feria 6 per annum" "Fridays, Ferial Office" "")
    ("04007000" "Sabbato per annum" "Saturdays, Ferial Office" "")
    ("04008000" "Hebdomadae per annum" "Weekdays, Ferial Office" "")
    ("05000000" "In tempore Epiphaniae" "General, after Epiphany" "")
    ("05001000" "Dominicae post Epiphaniam" "Sundays after Epiphany" "")
    ("05002000" "Feria 2 post Epiphaniam" "Monday, week after Epiphany" "")
    ("05003000" "Feria 3 post Epiphaniam" "Tuesday, week after Epiphany" "")
    ("05004000" "Feria 4 post Epiphaniam" "Wednesday, week after Epiphany" "")
    ("05005000" "Feria 5 post Epiphaniam" "Thursday, week after Epiphany" "")
    ("05006000" "Feria 6 post Epiphaniam" "Friday, week after Epiphany" "")
    ("05007000" "Sabbato post Epiphaniam" "Saturday after Epiphany" "")
    ("05011000" "Dominica 1 post Epiphaniam/Dominica infra Octavas Epiphaniae" "1st Sunday after Epiphany" "")
    ("05021000" "Dominica 2 post Epiphaniam" "2nd Sunday after Epiphany" "")
    ("05021008" "Dominica 2 post Epiphaniam, infra octavas" "In 3rd week after Epiphany" "")
    ("05022000" "Feria 2 Hebdomada 2 post Epiphaniam" "Monday, 2nd week after Epiphany" "")
    ("05023000" "Feria 3 Hebdomada 2 post Epiphaniam" "Tuesday, 2nd week after Epiphany" "")
    ("05024000" "Feria 4 Hebdomada 2 post Epiphaniam" "Wednesday, 2nd week after Epiphany" "")
    ("05025000" "Feria 5 Hebdomada 2 post Epiphaniam" "Thursday, 2nd week after Epiphany" "")
    ("05026000" "Feria 6 Hebdomada 2 post Epiphaniam" "Friday, 2nd week after Epiphany" "")
    ("05027000" "Sabbato Hebdomada 2 post Epiphaniam" "Saturday, 2nd week after Epiphany" "")
    ("05031000" "Dominica 3 post Epiphaniam" "3rd Sunday after Epiphany" "")
    ("05032000" "Feria 2 Hebdomada 3 post Epiphaniam" "Monday, 3rd week after Epiphany" "")
    ("05033000" "Feria 3 Hebdomada 3 post Epiphaniam" "Tuesday, 3rd week after Epiphany" "")
    ("05034000" "Feria 4 Hebdomada 3 post Epiphaniam" "Wednesday, 3rd week after Epiphany" "")
    ("05037000" "Sabbato Hebdomada 3 post Epiphaniam" "Saturday, 3rd week after Epiphany" "")
    ("05041000" "Dominica 4 post Epiphaniam" "4th Sunday after Epiphany" "")
    ("05042000" "Feria 2 Hebdomada 4 post Epiphaniam" "Monday, 4th week after Epiphany" "")
    ("05047000" "Sabbato Hebdomada 4 post Epiphaniam" "Saturday, 4th week after Epiphany" "")
    ("05051000" "Dominica 5 post Epiphaniam" "5th Sunday after Epiphany" "")
    ("05052000" "Feria 2 Hebdomada 5 post Epiphaniam" "Monday, 5th week after Epiphany" "")
    ("05061000" "Dominica 6 post Epiphaniam" "6th Sunday after Epiphany" "")
    ("06011000" "Dominica Septuagesimae" "Septuagesima Sunday" "")
    ("06012000" "Feria 2 Septuagesimae" "Septuagesima Monday" "")
    ("06013000" "Feria 3 Septuagesimae" "Septuagesima Tuesday" "")
    ("06014000" "Feria 4 Septuagesimae" "Septuagesima Wednesday" "")
    ("06015000" "Feria 5 Septuagesimae" "Septuagesima Thursday" "")
    ("06016000" "Feria 6 Septuagesimae" "Septuagesima Friday" "")
    ("06017000" "Sabbato Septuagesimae" "Septuagesima Saturday" "")
    ("06018000" "Hebdomada Septuagesimae" "Week after Septuagesima" "")
    ("06021000" "Dominica Sexagesimae" "Sexagesima Sunday" "")
    ("06022000" "Feria 2 Sexagesimae" "Sexagesima Monday" "")
    ("06023000" "Feria 3 Sexagesimae" "Sexagesima Tuesday" "")
    ("06024000" "Feria 4 Sexagesimae" "Sexagesima Wednesday" "")
    ("06025000" "Feria 5 Sexagesimae" "Sexagesima Thursday" "")
    ("06026000" "Feria 6 Sexagesimae" "Sexagesima Friday" "")
    ("06027000" "Sabbato Sexagesimae" "Sexagesima Saturday" "")
    ("06028000" "Hebdomada Sexagesimae" "Week after Sexagesima" "")
    ("06031000" "Dominica Quinquagesimae" "Quinquagesima Sunday" "")
    ("06032000" "Feria 2 Quinquages." "Quinquagesima Monday" "")
    ("06033000" "Feria 3 Quinquages." "Quinquagesima Tuesday" "")
    ("06034000" "Feria 4 Cinerum" "Ash Wednesday" "")
    ("06035000" "Feria 5 post Cineres" "Thursday after Ash Wednesday" "")
    ("06036000" "Feria 6 post Cineres" "Friday after Ash Wednesday" "")
    ("06037000" "Sabbato post Cineres" "Saturday after Ash Wednesday" "")
    ("06038000" "Hebdomada Quinquagesimae" "Week after Quinquagesima" "")
    ("07000000" "In tempore Quadragesimae" "General, in Lent" "")
    ("07001000" "Dominica Quadragesimae" "Sundays in Lent" "")
    ("07002000" "Feria 2 Quadragesimae" "Mondays in Lent" "")
    ("07008000" "Feriae infra Quadragesima" "Weekdays in Quadragesima" "")
    ("07011000" "Dominica 1 Quadragesimae" "1st Sunday of Lent" "")
    ("07012000" "Feria 2 Hebdomada 1 Quadragesimae" "Monday, 1st week, Lent" "")
    ("07013000" "Feria 3 Hebdomada 1 Quadragesimae" "Tuesday, 1st week, Lent" "")
    ("07014000" "Feria 4 Hebdomada 1 Quadragesimae" "Wednesday, 1st week, Lent" "")
    ("07014009" "Feria 4 Quatuor Tempora Quadragesimae" "Ember Day, Lent: Wednesday" "")
    ("07015000" "Feria 5 Hebdomada 1 Quadragesimae" "Thursday, 1st week, Lent" "")
    ("07016000" "Feria 6 Hebdomada 1 Quadragesimae" "Friday, 1st week, Lent" "")
    ("07016009" "Feria 6 Quatuor Tempora Quadragesimae" "Ember Day, Lent: Friday" "")
    ("07017000" "Sabbato Hebdomada 1 Quadragesimae" "Saturday, 1st week, Lent" "")
    ("07018000" "Hebdomada 1 Quadragesimae" "1st week of Lent" "")
    ("07021000" "Dominica 2 Quadragesimae" "2nd Sunday of Lent" "")
    ("07022000" "Feria 2 Hebdomada 2 Quadragesimae" "Monday, 2nd week, Lent" "")
    ("07023000" "Feria 3 Hebdomada 2 Quadragesimae" "Tuesday, 2nd week, Lent" "")
    ("07024000" "Feria 4 Hebdomada 2 Quadragesimae" "Wednesday, 2nd week, Lent" "")
    ("07025000" "Feria 5 Hebdomada 2 Quadragesimae" "Thursday, 2nd week, Lent" "")
    ("07026000" "Feria 6 Hebdomada 2 Quadragesimae" "Friday, 2nd week, Lent" "")
    ("07027000" "Sabbato Hebdomada 2 Quadragesimae" "Saturday, 2nd week, Lent" "")
    ("07028000" "Hebdomada 2 Quadragesimae" "2nd week of Lent" "")
    ("07031000" "Dominica 3 Quadragesimae" "3rd Sunday of Lent" "")
    ("07032000" "Feria 2 Hebdomada 3 Quadragesimae" "Monday, 3rd week, Lent" "")
    ("07033000" "Feria 3 Hebdomada 3 Quadragesimae" "Tuesday, 3rd week, Lent" "")
    ("07034000" "Feria 4 Hebdomada 3 Quadragesimae" "Wednesday, 3rd week, Lent" "")
    ("07035000" "Feria 5 Hebdomada 3 Quadragesimae" "Thursday, 3rd week, Lent" "")
    ("07036000" "Feria 6 Hebdomada 3 Quadragesimae" "Friday, 3rd week, Lent" "")
    ("07037000" "Sabbato Hebdomada 3 Quadragesimae" "Saturday, 3rd week, Lent" "")
    ("07038000" "Hebdomada 3 Quadragesimae" "3rd week of Lent" "")
    ("07041000" "Dominica 4 Quadragesimae" "4th Sunday of Lent" "")
    ("07042000" "Feria 2 Hebdomada 4 Quadragesimae" "Monday, 4th week, Lent" "")
    ("07043000" "Feria 3 Hebdomada 4 Quadragesimae" "Tuesday, 4th week, Lent" "")
    ("07044000" "Feria 4 Hebdomada 4 Quadragesimae" "Wednesday, 4th week, Lent" "")
    ("07045000" "Feria 5 Hebdomada 4 Quadragesimae" "Thursday, 4th week, Lent" "")
    ("07046000" "Feria 6 Hebdomada 4 Quadragesimae" "Friday, 4th week, Lent" "")
    ("07047000" "Sabbato Hebdomada 4 Quadragesimae" "Saturday, 4th week, Lent" "")
    ("07048000" "Hebdomada 4 Quadragesimae" "4th week of Lent" "")
    ("07051000" "Dominica de Passione" "5th Sunday of Lent: Passion Sunday" "")
    ("07052000" "Feria 2 de Passione" "Monday, 5th week, Lent" "")
    ("07053000" "Feria 3 de Passione" "Tuesday, 5th week, Lent" "")
    ("07054000" "Feria 4 de Passione" "Wednesday, 5th week, Lent" "")
    ("07055000" "Feria 5 de Passione" "Thursday, 5th week, Lent" "")
    ("07056000" "Feria 6 de Passione" "Friday, 5th week, Lent" "")
    ("07057000" "Sabbato de Passione" "Saturday, 6th week, Lent" "")
    ("07058000" "Hebdomada de Passione" "5th week of Lent" "")
    ("07061000" "Dominica in Palmis" "Palm Sunday" "")
    ("07062000" "Feria 2 Hebdomadae Sanctae" "Monday, Holy Week" "")
    ("07063000" "Feria 3 Hebdomadae Sanctae" "Tuesday, Holy Week" "")
    ("07064000" "Feria 4 Hebdomadae Sanctae" "Wednesday, Holy Week" "")
    ("07065000" "Feria 5 in Cena Domini" "Holy Thursday: Maundy Thursday" "")
    ("07065010" "Ad Mandatum" "At the Mandatum: Foot-Washing" "")
    ("07066000" "Feria 6 in Parasceve" "Good Friday" "")
    ("07067000" "Sabbato Sancto" "Holy Saturday" "")
    ("07068000" "Hebdomada Sancta" "Holy Week" "")
    ("07069000" "In Triduum" "General, during the Triduum" "")
    ("08000000" "In tempore Paschae" "General, in Eastertide" "")
    ("08001000" "Dominicae in tempore Paschae" "Sundays in Eastertide" "")
    ("08002000" "Feria 2 in tempore Paschae" "Mondays in Eastertide" "")
    ("08003000" "Feria 3 in tempore Paschae" "Tuesdays in Eastertide" "")
    ("08004000" "Feria 4 in tempore Paschae" "Wednesdays in Eastertide" "")
    ("08005000" "Feria 5 in tempore Paschae" "Thursdays in Eastertide" "")
    ("08006000" "Feria 6 in tempore Paschae" "Fridays in Eastertide" "")
    ("08007000" "Sabbato in tempore Paschae" "Saturdays in Eastertide" "")
    ("08008000" "Hebdomadae in tempore Paschae" "Weekdays in Eastertide" "")
    ("08011000" "Dominica Resurrectionis" "Easter Sunday" "")
    ("08011008" "Infra octavis Paschae" "In week after Easter Sunday" "")
    ("08012000" "Feria 2 post Pascha" "Easter Monday" "")
    ("08013000" "Feria 3 post Pascha" "Easter Tuesday" "")
    ("08014000" "Feria 4 post Pascha" "Easter Wednesday" "")
    ("08015000" "Feria 5 post Pascha" "Easter Thursday" "")
    ("08016000" "Feria 6 post Pascha" "Easter Friday" "")
    ("08017000" "Sabbato in Albis" "Easter Saturday" "")
    ("08020100" "Pascha Annotinum" "Memorial of past year's Easter" "")
    ("08021000" "Dominica in Octavis Paschae/Dominica in Albis" "Octave of Easter" "")
    ("08021008" "Hebdomada 1 post Octavas Paschae" "In 2nd week after Easter" "")
    ("08022000" "Feria 2 post Octavas Paschae" "Monday, 2nd week after Easter" "")
    ("08023000" "Feria 3 post Octavas Paschae" "Tuesday, 2nd week after Easter" "")
    ("08024000" "Feria 4 post Octavas Paschae" "Wednesday, 2nd week after Easter" "")
    ("08025000" "Feria 5 post Octavas Paschae" "Thursday, 2nd week after Easter" "")
    ("08026000" "Feria 6 post Octavas Paschae" "Friday, 2nd week after Easter" "")
    ("08026010" "De Sancta Lancea" "The Holy Lance; on the Friday after the Octave of Easter" "")
    ("08027000" "Sabbato post Octavas Paschae" "Saturday, 2nd week after Easter" "")
    ("08028000" "Hebdomada 2 post Pascha" "2nd week after Easter" "")
    ("08031000" "Dominica 2 post Pascha" "2nd Sunday after Easter" "")
    ("08031008" "Dominica 2 post Pascha, infra octavas" "In 3rd week after Easter" "")
    ("08032000" "Feria 2 Hebdomada 3 Paschae" "Monday, 3rd week after Easter" "")
    ("08033000" "Feria 3 Hebdomada 3 Paschae" "Tuesday, 3rd week after Easter" "")
    ("08034000" "Feria 4 Hebdomada 3 Paschae" "Wednesday, 3rd week after Easter" "")
    ("08035000" "Feria 5 Hebdomada 3 Paschae" "Thursday, 3rd week after Easter" "")
    ("08036000" "Feria 6 Hebdomada 3 Paschae" "Friday, 3rd week after Easter" "")
    ("08037000" "Sabbato 3 post Pascha" "Saturday, 3rd week after Easter" "")
    ("08038000" "Hebdomada 3 post Pascha" "3rd week after Easter" "")
    ("08041000" "Dominica 3 post Pascha" "3rd Sunday after Easter" "")
    ("08041008" "Dominica 3 post Pascha, infra octavas" "In 4th week after Easter" "")
    ("08042000" "Feria 2 Hebdomada 4 Paschae" "Monday, 4th week after Easter" "")
    ("08043000" "Feria 3 Hebdomada 4 Paschae" "Tuesday, 4th week after Easter" "")
    ("08044000" "Feria 4 Hebdomada 4 Paschae" "Wednesday, 4th week after Easter" "")
    ("08045000" "Feria 5 Hebdomada 4 Paschae" "Thursday, 4th week after Easter" "")
    ("08046000" "Feria 6 Hebdomada 4 Paschae" "Friday, 4th week after Easter" "")
    ("08046010" "Compassio Mariae in tempore Paschae" "The Sorrows of Mary, celebrated Friday after third" "")
    ("08047000" "Sabbato 4 post Pascha" "Saturday, 4th week after Easter" "")
    ("08048000" "Hebdomada 4 post Pascha" "4th week after Easter" "")
    ("08051000" "Dominica 4 post Pascha" "4th Sunday after Easter" "")
    ("08051008" "Dominica 4 post Pascha, infra octavas" "In 5th week after Easter" "")
    ("08052000" "Feria 2 Hebdomada 5 Paschae" "Monday, 5th week after Easter" "")
    ("08053000" "Feria 3 Hebdomada 5 Paschae" "Tuesday, 5th week after Easter" "")
    ("08054000" "Feria 4 Hebdomada 5 Paschae" "Wednesday, 5th week after Easter" "")
    ("08055000" "Feria 5 Hebdomada 5 Paschae" "Thursday, 5th week after Easter" "")
    ("08056000" "Feria 6 Hebdomada 5 Paschae" "Friday, 5th week after Easter" "")
    ("08057000" "Sabbato 5 post Pascha" "Saturday, 6th week after Easter" "")
    ("08058000" "Hebdomada 5 post Pascha" "5th week after Easter" "")
    ("08061000" "Dominica 5 post Pascha" "5th Sunday after Easter" "")
    ("08062000" "Feria 2 in Letaniis" "Rogation Monday" "")
    ("08063000" "Feria 3 in Letaniis" "Rogation Tuesday" "")
    ("08064000" "Feria 4 in Letaniis" "Rogation Wednesday" "")
    ("08065000" "Ascensio Domini" "Ascension Thursday" "")
    ("08065008" "Ascensio Domini, infra octavas" "In week after Ascension" "")
    ("08066000" "Feria 6 post Ascensionem" "Friday after Ascension" "")
    ("08067000" "Sabbato post Ascensionem" "Saturday after Ascension" "")
    ("08068000" "Hebdomada 6 post Pascha" "6th week after Easter" "")
    ("08068010" "In Letaniis" "General, Rogation Days" "")
    ("08071000" "Dominica post Ascensionem" "Sunday after Ascension" "")
    ("08072000" "Feria 2 post Ascensionem" "Monday, week after Ascension" "")
    ("08073000" "Feria 3 post Ascensionem" "Tuesday, week after Ascension" "")
    ("08074000" "Feria 4 post Ascensionem" "Wednesday, week after Ascension" "")
    ("08075000" "Octava Ascens. Domini" "Octave of Ascension" "")
    ("08076000" "Feria 6 post Octavas Ascensionis" "Friday, week after Ascension" "")
    ("08077000" "Vig. Pentecostes" "Eve of Pentecost" "")
    ("08077100" "Sabbato post Octavas Ascensionis" "Saturday, week after Ascension" "")
    ("08081000" "Dominica Pentecostes" "Pentecost Sunday: Whitsunday" "")
    ("08081008" "Infra Hebdomada Pentecostes" "In week after Pentecost" "")
    ("08082000" "Feria 2 Pentecosten" "Pentecost Monday" "")
    ("08083000" "Feria 3 Pentecosten" "Pentecost Tuesday" "")
    ("08084000" "Feria 4 Pentecosten" "Pentecost Wednesday" "")
    ("08085000" "Feria 5 Pentecosten" "Pentecost Thursday" "")
    ("08086000" "Feria 6 Pentecosten" "Pentecost Friday" "")
    ("08087000" "Sabbato Pentecosten" "Pentecost Saturday" "")
    ("08091000" "Octava Pentecostes" "Octave of Pentecost" "")
    ("09001000" "Dominicae post Pentecosten" "Sundays after Pentecost" "")
    ("09008000" "Hebdomadae post Pentecosten" "Weekdays after Pentecost" "")
    ("09011000" "De Trinitate" "Trinity Sunday" "")
    ("09011008" "De Trinitate, infra octavas" "In the week after Trinity Sunday" "")
    ("09011010" "Dominica 1 post Pentecosten" "1st Sunday after Pentecost" "")
    ("09013000" "Feria 3 Trinitate" "Trinity Tuesday" "")
    ("09014000" "Feria 4 Trinitate" "Trinity Wednesday" "")
    ("09015000" "Corporis Christi" "Corpus Christi" "")
    ("09015008" "Corporis Christi, infra octavas" "In week after Corpus Christi" "")
    ("09016000" "Feria 6 Corpus Christi" "Friday after Corpus Christi" "")
    ("09017000" "Sabbato Corpus Christi" "Saturday after Corpus Christi" "")
    ("09021000" "Dominica 2 post Pentecosten/Dominica 1 post octavas Pentecosten" "2nd Sunday after Pentecost" "")
    ("09021008" "Dominica 2 post Pentecosten, infra octavas" "In 3rd week after Pentecost" "")
    ("09021010" "Dominica post Corpus Christi" "Sunday after Corpus Christi" "")
    ("09022000" "Feria 2 Corpus Christi" "Monday after Corpus Christi" "")
    ("09023000" "Feria 3 Corpus Christi" "Tuesday after Corpus Christi" "")
    ("09024000" "Feria 4 Corpus Christi" "Wednesday after Corpus Christi" "")
    ("09025000" "Octava Corporis Christi" "Octave of Corpus Christi" "")
    ("09027000" "Sabbato post Octavas Corporis Christi" "Saturday after Octave of Corpus Christi" "")
    ("09031000" "Dominica 3 post Pentecosten" "3rd Sunday after Pentecost" "")
    ("09041000" "Dominica 4 post Pentecosten" "4th Sunday after Pentecost" "")
    ("09051000" "Dominica 5 post Pentecosten" "5th Sunday after Pentecost" "")
    ("09061000" "Dominica 6 post Pentecosten" "6th Sunday after Pentecost" "")
    ("09071000" "Dominica 7 post Pentecosten" "7th Sunday after Pentecost" "")
    ("09081000" "Dominica 8 post Pentecosten" "8th Sunday after Pentecost" "")
    ("09091000" "Dominica 9 post Pentecosten" "9th Sunday after Pentecost" "")
    ("09101000" "Dominica 10 post Pentecosten" "10th Sunday after Pentecost" "")
    ("09111000" "Dominica 11 post Pentecosten" "11th Sunday after Pentecost" "")
    ("09121000" "Dominica 12 post Pentecosten" "12th Sunday after Pentecost" "")
    ("09131000" "Dominica 13 post Pentecosten" "13th Sunday after Pentecost" "")
    ("09141000" "Dominica 14 post Pentecosten" "14th Sunday after Pentecost" "")
    ("09151000" "Dominica 15 post Pentecosten" "15th Sunday after Pentecost" "")
    ("09161000" "Dominica 16 post Pentecosten" "16th Sunday after Pentecost" "")
    ("09171000" "Dominica 17 post Pentecosten" "17th Sunday after Pentecost" "")
    ("09181000" "Dominica 18 post Pentecosten" "18th Sunday after Pentecost" "")
    ("09191000" "Dominica 19 post Pentecosten" "19th Sunday after Pentecost" "")
    ("09201000" "Dominica 20 post Pentecosten" "20th Sunday after Pentecost" "")
    ("09211000" "Dominica 21 post Pentecosten" "21st Sunday after Pentecost" "")
    ("09221000" "Dominica 22 post Pentecosten" "22nd Sunday after Pentecost" "")
    ("09231000" "Dominica 23 post Pentecosten" "23rd Sunday after Pentecost" "")
    ("09241000" "Dominica 24 post Pentecosten" "24th Sunday after Pentecost" "")
    ("09251000" "Dominica 25 post Pentecosten" "25th Sunday after Pentecost" "")
    ("09261000" "Dominica 26 post Pentecosten" "26th Sunday after Pentecost" "")
    ("09271000" "Dominica 27 post Pentecosten" "27th Sunday after Pentecost" "")
    ("09281000" "Dominica 28 post Pentecosten" "28th Sunday after Pentecost" "")
    ("10000000" "In aestate" "General, in summer" "")
    ("10001000" "Dominicae in aestate" "Sundays in summer" "")
    ("10002000" "Feria 2 in aestate" "Mondays in summer" "")
    ("10003000" "Feria 3 in aestate" "Tuesdays in summer" "")
    ("10004000" "Feria 4 in aestate" "Wednesdays in summer" "")
    ("10005000" "Feria 5 in aestate" "Thursdays in summer" "")
    ("10006000" "Feria 6 in aestate" "Fridays in summer" "")
    ("10007000" "Sabbato in aestate" "Saturdays in summer" "")
    ("10100000" "De Regum" "Summer Histories, from Kings" "")
    ("10200000" "De Sapientia" "Summer Histories, from Wisdom" "")
    ("10300000" "De Job" "Summer Histories, from Job" "")
    ("10400000" "De Tobia" "Summer Histories, from Tobias" "")
    ("10500000" "De Judith" "Summer Histories, from Judith" "")
    ("10600000" "De Esther" "Summer Histories, from Esther" "")
    ("10700000" "De Esdras" "Summer Histories, from Esdras" "")
    ("10800000" "De Machabaeis" "Summer Histories, from Maccabees" "")
    ("10900000" "De Prophetis" "Summer Histories, from the Prophets" "")
    ("11080100" "Dominicae mensis Augusti" "Sundays in August" "")
    ("11081100" "Dominica 1 mensis Augusti" "First Sunday in August" "")
    ("11082100" "Dominica 2 mensis Augusti" "Second Sunday in August" "")
    ("11090100" "Dominicae mensis Sept." "Sundays in September" "")
    ("11090409" "Feria 4 Quatuor Tempora Sept." "Ember Day, September: Wednesday" "")
    ("11090609" "Feria 6 Quatuor Tempora Sept." "Ember Day, September: Friday" "")
    ("11090709" "Sabbato Quatuor Tempora Sept." "Ember Day, September: Saturday" "")
    ("11100100" "Dominicae mensis Octobris" "Sundays in October" "")
    ("11110100" "Dominicae mensis Nov." "Sundays in November" "")
    ("13001000" "Pro Defunctis" "Office for the Dead" "")
    ("16001000" "Ad Benedicite" "Antiphons for Benedicite canticle" "")
    ("16002000" "Ad Benedictus" "Antiphons for Benedictus canticle" "")
    ("16003000" "Ad Magnificat" "Antiphons for Magnificat canticle" "")
    ("16004000" "Invitatoria" "Invitatory Antiphons or Psalms" "")
    ("16005000" "Ad Nunc Dimittis" "Antiphons for Nunc Dimittis canticle" "")
    ("16006000" "Ad Completorium" "For Compline" "")
    ("16007000" "Hymni" "Hymns" "")
    ("16008000" "Conductus" "Conductus" "")
    ("16009000" "Ad Processionem" "For Processions" "")
    ("16010000" "Ad Aquam Benedictio" "For the Blessing of Water" "")
    ("16011000" "In Dedicatione Altaris" "Commemoration of an Altar's Dedication" "")
    ("17001000" "Additamenta" "Added Items" "")
    ("12000000" "Officia votiva" "Votive Offices" "")
    ("12000000" "Officia votiva" "Votive Offices" "")
    ("12001000" "Commune Apostolorum" "Common of Apostles" "")
    ("12001100" "Commune unius Apostoli" "Common of one Apostle" "")
    ("12002000" "Commune unius Martyris" "Common of one Martyr" "")
    ("12002100" "Commune unius Martyris et Pontificis" "Common of one Martyr \(Pope\)" "")
    ("12002200" "Commune Martyris non Pontificis" "Common of one Martyr \(not Pope\)" "")
    ("12003000" "Commune plurimorum Martyrum" "Common of several Martyrs" "")
    ("12003008" "Commune plurimorum Martyrum; infra octavas" "Common of several Martyrs, in week of" "")
    ("12004000" "Commune unius Confessoris" "Common of one Confessor" "")
    ("12004100" "Commune unius Confessoris et Pontificis" "Common of one Confessor \(Pope\)" "")
    ("12004200" "Commune unius Confessoris et Abbatis" "Common of one Confessor \(Abbot\)" "")
    ("12004300" "Commune unius Confessoris et Episcopis" "Common of one Confessor \(Bishop\)" "")
    ("12004308" "Commune unius Confessoris et Episcopis; infra octavas" "Common of one Confessor \(Bishop\), in week of" "")
    ("12004400" "Commune Confessoris non Episcopis" "Common of one Confessor \(not Bishop\)" "")
    ("12004500" "Commune unius Confessoris et Doctoris" "Common of one Confessor \(Doctor\)" "")
    ("12004600" "Commune plurimorum Confessorum non Pontificorum" "Common of several Confessors \(not Popes\)" "")
    ("12005000" "Commune plurimorum Confessorum" "Common of several Confessors" "")
    ("12005100" "Commune plorimorum Confessorum et Pontificorum" "Common of several Confessors \(Popes\)" "")
    ("12007000" "Commune Virginum" "Common of several Virgins" "")
    ("12007100" "Commune unius Virginis" "Common of one Virgin" "")
    ("12007200" "Commune Virginis non Martyris" "Common of one Virgin \(not Martyr\)" "")
    ("12007300" "Commune Virginum et Martyrum" "Common of Virgin Martyrs" "")
    ("12008000" "In Dedicatione Ecclesiae" "Dedication of a Church" "")
    ("12008007" "Dominica post Dedicatione Ecclesiae" "Sunday after Dedication of Church" "")
    ("12008008" "In Dedicatione Ecclesiae; infra octavas" "In week after Dedication of Church" "")
    ("12008100" "Octava Dedicationis Ecclesiae" "Octave of Dedication of Church" "")
    ("12009000" "Commune Regum" "Common of Kings" "")
    ("12010000" "Commune unius Abbatis" "Common of one Abbot" "")
    ("12011000" "Commune Evangelistarum" "Common of Evangelists" "")
    ("12012000" "Commune Coniungium" "Common of Matrons" "")
    ("12013000" "De Angelis" "Memorial chants for Angels" "")
    ("12014000" "De Patronis" "Memorial chants for Patrons" "")
    ("12801100" "Commune Apostolorum sive Martyres in tempore Paschae" "Common of Martyr Apostles in Eastertide" "")
    ("12802000" "Commune unus Martyris in tempore Paschae" "Common of one Martyr in Eastertide" "")
    ("12803000" "Commune plurimorum Martyrum in tempore Paschae" "Common of many Martyrs in Eastertide" "")
    ("12804000" "Commune Confessorum non Pontificorum in tempore Paschae" "Common, Confessors \(not Popes\) in Eastertide" "")
    ("12805000" "Commune unius Confessoris in tempore Paschae" "Common of one Confessor in Eastertide" "")
    ("12805100" "Commune plurimorum Confessorum in tempore Paschae" "Common of several Confessors, in Eastertide" "")
    ("12806000" "De Sanctis in tempore Paschae" "Common of Saints in Eastertide" "")
    ("12807000" "Commune Virginum in tempore Paschae" "Common of several Virgins in Eastertide" "")
    ("12808000" "Commune Apostolorum in tempore Paschae" "Common of Apostles in Eastertide" "")
    ("12809000" "Martyrum sive Confessorum in tempore Paschae" "Common of Martyrs and Confessors in Eastertide" "")
    ("14010200" "S. Basilii" "Basil of Ancyra, Martyr" "January 2")
    ("14010300" "S. Genovefae" "Genevieve \(Genovefa\), Virgin" "January 3")
    ("14010500" "S. Simeonis Stylitae" "Simeon the Stylite" "January 5")
    ("14010510" "Octava S. Thomae Cantuarensis" "Octave of Thomas Becket, Bishop of Canterbury" "January 5")
    ("14010520" "S. Edwardi Conf." "Edward the Confessor, King of England" "January 5")
    ("14010530" "S. Severini, Apost." "Severinus, Apostle of Noricum" "January 5")
    ("14010700" "S. Valentini, Epi." "Valentine, Bishop" "January 7")
    ("14010800" "S. Wulsini" "Wulsin, Bishop of Sherborne" "January 8")
    ("14010810" "S. Gudulae" "Gudula, Virgin" "January 8")
    ("14011000" "S. Willelmi" "William, Archbishop of Bourges" "January 10")
    ("14011400" "S. Hilarii" "Hilary, Bishop of Poitiers, Doctor" "January 14")
    ("14011410" "S. Felicis Nolani" "Felix of Nola, Confessor" "January 14")
    ("14011420" "S. Pontiani" "Pontianus, Martyr at Spoleto" "January 14")
    ("14011500" "S. Pauli Heremitae" "Paul the Hermit" "January 15")
    ("14011510" "S. Mauri" "Maurus, Abbot" "January 15")
    ("14011518" "S. Mauri, infra octavas" "In week after Maurus" "")
    ("14011520" "Inventio S. Firmini" "Finding of Firminus's relics" "January 15")
    ("14011530" "S. Macarii" "Macarius the Elder, Hermit" "January 15")
    ("14011600" "S. Marcelli" "Marcellus I, Pope and Martyr" "January 16")
    ("14011610" "S. Fursei" "Fursey, Abbot" "January 16")
    ("14011700" "S. Antonii" "Antony, Abbot" "January 17")
    ("14011710" "S. Sabini" "Sabinus, Bishop of Piacenza" "January 17")
    ("14011720" "S. Speusippi" "Speusippus and Meleusippus, Martyrs" "Jan. 17")
    ("14011800" "S. Priscae" "Prisca, Virgin Martyr" "January 18")
    ("14011900" "SS. Marii, Marthae" "Marius, Martha, et al., Martyrs" "January 19")
    ("14011910" "Transl. S. Hugonis" "Moving of Hugo's relics" "January 19")
    ("14011920" "S. Wulstani" "Wulfstan, Bishop of Worcester" "January 19")
    ("14011928" "S. Wulstani, infra octavas" "In week after Wulfstan" "")
    ("14011930" "S. Launomari" "Launomarus, Abbot of Corbie" "January 19")
    ("14012000" "Fabiani, Sebastiani" "Pope Fabian and Sebastian, Martyrs" "January 20")
    ("14012100" "S. Agnetis" "Agnes, Virgin Martyr" "January 21")
    ("14012108" "S. Agnetis, infra octavas" "In week after Agnes" "")
    ("14012110" "S. Meginrati" "Meinrad, Hermit of Einsiedeln" "January 21")
    ("14012200" "S. Vincentii" "Vincent of Saragossa, Martyr" "January 22")
    ("14012208" "S. Vincentii, infra octavas" "In week after Vincent" "")
    ("14012210" "S. Anastasii" "Anastasius the Persian, Martyr" "January 22")
    ("14012300" "S. Emerentianae" "Emerentiana, Virgin Martyr" "January 23")
    ("14012400" "S. Timothei" "Timothy, Disciple of Paul, Bishop" "January 24")
    ("14012410" "Elevat. S. Aubertii" "Elevation of Aubertus's relics" "January 24")
    ("14012500" "Conversio S. Pauli" "Conversion of St. Paul" "January 25")
    ("14012510" "S. Praeiecti" "Praeiectus \(Prix\), Bishop Martyr" "January 25")
    ("14012600" "S. Polycarpi" "Polycarp, Bishop of Smyrna, Martyr" "January 26")
    ("14012610" "S. Paulae" "Paula, Widow" "January 26")
    ("14012700" "S. Joannis Chrysostomi" "John Chrysostom, Doctor" "January 27")
    ("14012710" "S. Juliani, Epi." "Julian, Bishop of Le Mans" "January 27")
    ("14012800" "Octava S. Agnetis" "Octave of Agnes" "January 28")
    ("14012900" "S. Valerii" "Valerius, Bishop of Saragossa" "January 29")
    ("14012910" "S. Sulpicii Severi" "Sulpicius Severus, Bishop of Bourges" "January 29")
    ("14013000" "S. Aldegundis" "Aldegundis, Virgin" "January 30")
    ("14013010" "S. Balthildis" "Balthildis \(Bathildis\), Queen" "January 30")
    ("14013100" "S. Cyri" "Cyrus and John, Martyrs" "January 31")
    ("14020100" "S. Brigidae" "Brigid \(Bride\), Abbess" "February 1")
    ("14020110" "S. Ignatii" "Ignatius, Bishop of Antioch, Martyr" "February 1")
    ("14020120" "S. Valerici" "Valericus, Hermit" "February 1")
    ("14020200" "Purificatio Mariae" "Purification of Mary \(Candlemas\)" "February 2")
    ("14020208" "Purificatio Mariae, infra octavas" "In week after Purification of Mary" "")
    ("14020300" "S. Blasii" "Blaise, Bishop of Sebastea, Martyr" "February 3")
    ("14020308" "S. Blasii, infra octavas" "In week after Blaise" "")
    ("14020500" "S. Agathae" "Agatha, Virgin Martyr" "February 5")
    ("14020508" "S. Agathae, infra octavas" "In week after Agatha" "")
    ("14020600" "S. Vedasti" "Vaast \(Vedast\), Bishop of Arras" "February 6")
    ("14020607" "Dominica post S. Vedasti" "Sunday after Vaast" "")
    ("14020608" "S. Vedasti, infra octavas" "In week after Vaast" "")
    ("14020610" "S. Dorotheae" "Dorothy, Virgin Martyr" "February 6")
    ("14020620" "S. Amandi" "Amand \(Amandus\), Bishop" "February 6")
    ("14021000" "S. Scholasticae" "Scholastica, Virgin" "February 10")
    ("14021010" "Octava S. Blasii" "Octave of Blaise" "February 10")
    ("14021210" "S. Modesti" "Modestus, Martyr" "February 12")
    ("14021300" "Octava S. Vedasti" "Octave of Vaast" "February 13")
    ("14021310" "Octava S. Amandi" "Octave of Amand" "February 13")
    ("14021400" "S. Valentini" "S. Valentine, Martyr" "February 14")
    ("14021500" "SS. Faustini,Jovitae" "Faustinus and Jovita, Martyrs" "February 15")
    ("14021600" "S. Julianae" "Juliana, Virgin Martyr" "February 16")
    ("14022200" "Cathedra S. Petri" "St. Peter's Chair" "February 22")
    ("14022300" "S. Milburgae" "Milburga, Abbess of Wenlock" "February 23")
    ("14022400" "S. Matthiae" "Matthias, Apostle" "February 24")
    ("14022500" "S. Walburgae" "Walburga, Virgin Abbess" "February 25")
    ("14022800" "S. Oswaldi, Epi." "Oswald, Bishop of Worcester" "February 28")
    ("14030100" "S. Albini, Epi." "Albinus \(Aubin\), Bishop of Angers" "March 1")
    ("14030110" "S. David" "David of Wales, Monk and Bishop" "March 1")
    ("14030300" "S. Kunegundis" "Cunegund \(Kunegunde\), Queen" "March 3")
    ("14030600" "SS. Perpetuae,Felic." "Perpetua and Felicity, Martyrs" "March 6")
    ("14031100" "S. Vindiciani" "Vindician, Bishop of Cambrai" "March 11")
    ("14031200" "S. Gregorii" "Gregory the Great, Pope and Doctor" "March 12")
    ("14031600" "SS. Helari, Tatiani" "Hilary \(Bishop of Aquileia\) and Tatianus, Martyrs" "March 16")
    ("14031700" "S. Gertrudis" "Gertrude of Nivelles, Virgin" "March 17")
    ("14032000" "S. Cuthberti" "Cuthbert, Bishop of Lindisfarne" "March 20")
    ("14032100" "S. Benedicti" "Benedict, Abbot" "March 21")
    ("14032500" "Annuntiatio Mariae" "Annunciation of Mary \(Lady Day\)" "March 25")
    ("14032508" "Annuntiatio Mariae, infra octavas" "In week after Annunciation of Mary" "")
    ("14040200" "S.Mariae Aegyptiacae" "Mary the Egyptian, Penitent" "April 2")
    ("14040400" "S. Ambrosii" "Ambrose, Bishop of Milan, Doctor" "April 4")
    ("14040900" "S. Waldetrudis" "Waldetrudis \(Waudru\), Widow" "April 9")
    ("14041100" "S. Guthlaci" "Guthlac, Hermit of Croyland" "April 11")
    ("14041400" "Tiburtii, Valeriani" "Tiburtius, Valerian and Maximus, Martyrs" "April 14")
    ("14041900" "S. Leonis, Pont." "Leo IX, Pope" "April 19")
    ("14042200" "Inventio S. Dionysii" "Finding of Denis's relics" "April 22")
    ("14042210" "S. Opportunae" "Opportuna, Virgin and Abbess" "April 22")
    ("14042300" "S. Georgii" "George, Martyr" "April 23")
    ("14042400" "S. Egberti" "Egbert of Iona, Bishop" "April 24")
    ("14042410" "S. Ivonis" "Ivo, Bishop of Persia" "April 24")
    ("14042500" "S. Marci" "Mark, Evangelist" "April 25")
    ("14042800" "S. Vitalis" "Vitalis and Valeria, Martyrs" "April 28")
    ("14042810" "Transl. Petri Alcan." "Moving of Peter of Alcantara's Relics" "April 28")
    ("14042900" "S. Petri, Mart." "Peter the Martyr, Dominican Friar and Priest" "April 29")
    ("14043000" "Octava S. Georgii" "Octave of George" "April 30")
    ("14043010" "S. Eutropii" "Eutropius, Bishop of Saintes, Martyr" "April 30")
    ("14050100" "SS. Philippi, Jacobi" "Philip and James, Apostles" "May 1")
    ("14050108" "SS.Philippi,Jacobi, infra octavas" "In week after Philip and James" "")
    ("14050110" "Elev. S. Elis. Hung." "Elevation of Elizabeth's relics" "May 1")
    ("14050118" "Elev. S. Elis.Hung., infra octavas" "In week after Elizabeth's Elevation" "")
    ("14050120" "S. Orientii" "Orientius \(Orens\), Bishop" "May 1")
    ("14050130" "S. Amatoris" "Amator \(Amatre\), Bishop of Auxerre" "May 1")
    ("14050140" "S. Sigismundi" "Sigismund, King of Burgundy, Martyr" "May 1")
    ("14050150" "Transl. S. Walburgae" "Moving of Walburga's relics" "May 1")
    ("14050200" "S. Athanasii" "Athanasius, Archbishop of Alexandria" "May 2")
    ("14050300" "Inventio S. Crucis" "Finding of the Holy Cross" "May 3")
    ("14050308" "Inventio S. Crucis, infra octavas" "In week after the Finding of the Cross" "")
    ("14050310" "SS.Alexandri et Soc." "Alexander and Eventius, Martyrs" "May 3")
    ("14050320" "S. Juvenalis" "Juvenal, Bishop of Narni" "May 3")
    ("14050330" "S. Helenae" "Helen, Finder of the True Cross" "May 3")
    ("14050400" "S. Floriani" "Florian, Martyr" "May 4")
    ("14050410" "S. Godehardi" "Godehard \(Gothard\), Bishop of Hildesheim" "May 4")
    ("14050420" "S. Judae Quiriaci" "Judas Quiriacus \(Cyriacus\), Bishop" "May 4")
    ("14050600" "S. Jo. Port. Lat." "St. John before the Latin Gate" "May 6")
    ("14050700" "Transl. S. Stephani" "Moving of Stephan's rellics" "May 7")
    ("14050800" "Appar. S. Michaelis" "Appearing of Michael the Archangel" "May 8")
    ("14050810" "S. Victoris Mauri" "Victor Maurus, Martyr" "May 8")
    ("14050830" "Octava Philippi,Jacobi" "Octave of Philip and James, Apostles" "May 8")
    ("14050840" "S. Wironi" "Wiro, Apostle of southern Netherlands" "May 8")
    ("14050900" "Transl. S. Nicolai" "Moving of Nicholas's relics" "May 9")
    ("14051000" "SS.Gordiani,Epimachi" "Gordian and Epimachus, Martyrs" "May 10")
    ("14051100" "S. Mamerti" "Mamertus, Bishop of Vienne" "May 11")
    ("14051110" "S. Gengulfi" "Gengoul \(Gengulfus\), Martyred Knight" "May 11")
    ("14051200" "S. Rictrudis" "Rictrudis, Widow" "May 12")
    ("14051210" "SS.Pancratii et Soc." "Pancras and Companions, Martyrs" "May 12")
    ("14051220" "Subventio S. Martini" "Hiding of Martin's relics" "May 12")
    ("14051230" "Transl. S. Mauritii" "Moving of Maurice's relics" "May 12")
    ("14051300" "S. Servatii" "Servais \(Servatius\), Bishop of Tongres" "May 13")
    ("14051400" "S. Pontii" "Pontius, Martyr" "May 14")
    ("14051500" "S. Euticii" "Euticius \(Eutice, Euthycius\), Martyr" "May 15")
    ("14051700" "Transl. S. Syri" "Moving of Syrus's relics" "May 17")
    ("14051900" "S. Hadulfi" "Hadulf, Abbot and Bishop of Arras" "May 19")
    ("14051910" "S. Pudentianae" "Pudentiana and Pudens, Martyrs" "May 19")
    ("14051920" "S. Dunstani" "Dunstan, Archbishop of Canterbury" "May 19")
    ("14052500" "S. Zenobii" "Zenobius, Bishop of Florence" "May 25")
    ("14052510" "S. Urbani" "Urban I, Pope and Martyr" "May 25")
    ("14052520" "Tres Mariae" "Mary, Mary Cleophae, Mary Salome" "May 25")
    ("14052600" "S. Bedae" "The Venerable Bede, Doctor" "May 26")
    ("14052610" "S. Augustini Cant." "Augustine \(Austin\), of Canterbury" "May 26")
    ("14052700" "S. Ragnulfi" "Ragnulf \(Renon\)" "May 27")
    ("14052800" "S. Germani Parisien." "Germanus \(Germain\), Bishop of Paris" "May 28")
    ("14052810" "S. Carauni" "Caraunus, Deacon and Martyr" "May 28")
    ("14052900" "S. Maximini" "Maximinus, Bishop of Trier" "May 29")
    ("14053100" "SS. Cantiorum" "Cantius, Cantianus &amp; Cantianilla, Martyrs" "May 31")
    ("14053110" "S. Petronillae" "Petronilla, Virgin" "May 31")
    ("14060100" "Ordinatio S. Oswaldi" "Ordination of Oswald" "June 1")
    ("14060200" "SS. Marcellini,Petri" "Marcellinus and Peter, Martyrs" "June 2")
    ("14060300" "S. Erasmi" "Erasmus, Bishop and Martyr" "June 3")
    ("14060500" "S. Bonifacii" "Boniface, Archbishop and Martyr" "June 5")
    ("14060700" "Transl. S. Wulstani" "Moving of Wulfstan's relics" "June 7")
    ("14060800" "S. Medardi" "Medard, Bishop of Vermandois" "June 8")
    ("14060900" "SS. Primi, Feliciani" "Primus and Felician, Martyrs" "June 9")
    ("14061000" "S. Landerici" "Landericus \(Landry\), Bishop of Paris" "June 10")
    ("14061100" "S. Barnabae" "Barnabas, Apostle" "June 11")
    ("14061200" "SS.Basilidis et Soc." "Basilides and Companions, Martyrs" "June 12")
    ("14061300" "S. Antonii Patavini" "Anthony of Padua, Doctor" "June 13")
    ("14061400" "S. Basilii, Doct." "Basil the Great, Doctor" "June 14")
    ("14061500" "S. Viti" "Vitus and Companions, Martyrs" "June 15")
    ("14061510" "SS. Viti, Modesti" "Vitus, Modestus and Crescentia, Martyrs" "June 15")
    ("14061520" "S. Landelini" "Landelinus, Abbot" "June 15")
    ("14061530" "S. Eadburgae" "Eadburga, Abbess at Winchester" "June 15")
    ("14061600" "S. Cyrici" "Cyricus and Julitta, Martyrs" "June 16")
    ("14061608" "S. Cyrici, infra octavas" "In week after Cyricus" "")
    ("14061700" "Transl. S. Aichardi" "Moving of Aichardus's relics" "June 17")
    ("14061800" "SS. Marci,Marcellini" "Mark and Marcellian, Martyrs" "June 18")
    ("14061900" "SS.Gervasii,Protasii" "Gervase and Protase, Martyrs" "June 19")
    ("14062000" "SS.Georgii,Adalberti" "George and Adalbert, Martyrs" "June 20")
    ("14062010" "Tr. S. Edwardi Mart." "Moving of Edward the Martyr's relics" "June 20")
    ("14062100" "S. Albini, Mart." "Albinus \(Alban\) of Mainz, Martyr" "June 21")
    ("14062110" "S. Leutfredi" "Leufred \(Leufroy\), Abbot" "June 21")
    ("14062200" "S. Paulini Nolansis" "Paulinus, Bishop of Nola" "June 22")
    ("14062210" "Transl. S. Lamberti" "Moving of Lambert's relics" "June 22")
    ("14062220" "SS. Acacii et Soc." "Acacius and Companions, Martyrs" "June 22")
    ("14062300" "Vig. S. Jo. Bapt." "Eve of John the Baptist" "June 23")
    ("14062310" "Octava S. Cyrici" "Octave of Cyricus" "June 23")
    ("14062400" "S. Joannis Baptistae" "John the Baptist" "June 24")
    ("14062407" "Dominica post S. Jo. Bapt." "Sunday after John the Baptist" "")
    ("14062408" "S. Joannis Bapt., infra octavas" "In week after John the Baptist" "")
    ("14062500" "Transl. S. Eligii" "Moving of Eligius's relics" "June 25")
    ("14062510" "Transl. S. Lebuini" "Moving of Liafwin's relics" "June 25")
    ("14062600" "SS. Joannis, Pauli" "John and Paul, Martyrs" "June 26")
    ("14062610" "S. Baboleni" "Babolenus, Abbot" "June 26")
    ("14062700" "S. Ladislai" "Ladislaus, King of Hungary" "June 27")
    ("14062800" "S. Leonis" "Leo the Great, Pope" "June 28")
    ("14062810" "Vig. SS. Petri,Pauli" "Eve of Peter and Paul" "June 28")
    ("14062820" "Vig. S. Petri" "Eve of Peter" "June 28")
    ("14062900" "SS. Petri, Pauli" "Peter and Paul, Apostles" "June 29")
    ("14062907" "Dominica infra Octavas Apostolorum" "Sunday after Peter and Paul" "")
    ("14062908" "SS. Petri et Pauli, infra octavas" "In week after Peter and Paul" "")
    ("14062910" "S. Petri" "Peter, Apostle" "June 29")
    ("14062918" "S. Petri, infra octavas" "In week of Peter \(Apostle\)" "")
    ("14063000" "S. Pauli" "Paul, Apostle" "June 30")
    ("14063008" "S. Pauli, infra octavas" "In week of Paul \(Apostle\)" "")
    ("14063010" "S. Martialis, Ep." "Martial, Bishop of Limoges" "June 30")
    ("14070100" "Octava S. Joannis Baptistae" "Octave of John the Baptist" "July 1")
    ("14070200" "Visitatio Mariae" "Visitation of Mary" "July 2")
    ("14070208" "Visitatio Mariae, infra octavas" "In week after Visitation of Mary" "")
    ("14070210" "Processi, Martiniani" "Processus and Martinian, Martyrs" "July 2")
    ("14070300" "Transl. S. Thomae" "Moving of Thomas's relics" "July 3")
    ("14070310" "S. Mustiolae" "Mustiola \(with Irenaeus\), Martyrs" "July 3")
    ("14070400" "Transl. S. Martini" "Moving of Martin's relics" "July 4")
    ("14070410" "Decoll. S. Antonini" "Beheading of Antoninus" "July 4")
    ("14070420" "S. Udalrici" "Ulric \(Udalricus\), Bishop of Augsburg" "July 4")
    ("14070600" "Octava Apostolorum" "Octave of Peter and Paul" "July 6")
    ("14070608" "Octava Apostolorum, infra octavas" "In week after Octave of Peter and Paul" "")
    ("14070610" "S. Goaris" "Goar, Hermit" "July 6")
    ("14070620" "Transl. S. Gudulae" "Moving of Gudula's relics" "July 6")
    ("14070700" "S. Willibaldi" "Willibald, Bishop" "July 7")
    ("14070710" "Transl. Thomae Cant." "Moving of Thomas Becket's Relics" "July 7")
    ("14070800" "S. Martialis, Apost." "Martial, Apostle of Limoges" "July 8")
    ("14070810" "SS. Kiliani et Soc." "Kilian and Companions, Martyrs" "July 8")
    ("14070900" "OctavaVisitatio Mariae" "Octave of Visitation of Mary" "July 9")
    ("14071000" "SS. Septem Fratrum" "Seven Brothers, Martyrs" "July 10")
    ("14071100" "Transl. S. Benedicti" "Moving of Benedict's relics" "July 11")
    ("14071108" "Transl. S. Benedicti, infra octavas" "In week after Benedict's Translation" "")
    ("14071200" "Hermagore, Fortunati" "Hermagoras and Fortunatus, Martyrs" "July 12")
    ("14071300" "S. Henrici Imper." "Henry, Emperor and Confessor" "July 13")
    ("14071310" "S. Mildrithae" "Mildred, Abbess of Minster-in-Thanet" "July 13")
    ("14071400" "S. Madelgari" "Vincent \(ne Madelgar\), Abbot" "July 14")
    ("14071410" "Vig. Rel. S. Vedasti" "Eve of Return of Vaast's relics" "July 14")
    ("14071500" "Relatio S. Vedasti" "Return of Vaast's relics" "July 15")
    ("14071507" "Dominica post Relatione S. Vedasti" "Sunday after Return of Vaast's relics" "")
    ("14071508" "Infra Octavis Relationis S. Vedasti" "In week after Return of Vaast" "")
    ("14071510" "Divisio Apostolorum" "Sending forth of the Apostles" "July 15")
    ("14071520" "S. Swithuni" "Swithun, Bishop of Winchester" "July 15")
    ("14071700" "S. Alexii" "Alexis, the Man of God" "July 17")
    ("14071710" "S. Kenelmi" "Kenelm, Prince of Mercian Royal Family" "July 17")
    ("14071800" "Octava Tr. S.Benedicti" "Octave of Benedict's Translation" "July 18")
    ("14071810" "S. Arnulfi Metensis" "Arnulfus \(Arnoul\), Bishop of Metz" "July 18")
    ("14072000" "S. Vulmari" "Vulmar, Abbot" "July 20")
    ("14072010" "S. Margaritae" "Margaret \(Marina\), Virgin Martyr" "July 20")
    ("14072100" "S. Praxedis" "Praxedes, Virgin" "July 21")
    ("14072110" "SS. Victoris et Soc." "Victor of Marseilles et al., Martyrs" "July 21")
    ("14072200" "S. Mariae Magdalenae" "Mary Magdalene" "July 22")
    ("14072207" "Dominica post S. Mariae Mag." "Sunday after Mary Magdalene" "")
    ("14072208" "S. Mariae Mag., infra octavas" "In week after Mary Magdalene" "")
    ("14072210" "Octava Rel. S. Vedasti" "Octave of Return of Vaast's relics" "July 22")
    ("14072220" "S. Wandregisili" "Wandregisilus, Abbot of Fontenelle" "July 22")
    ("14072300" "S. Liborii" "Liborius, Confessor &amp; Bishop of Lemans" "July 23")
    ("14072310" "S. Joannis Cassiani" "John Cassian, Abbot" "July 23")
    ("14072320" "S. Apollinaris" "Apollinaris, Bishop of Ravenna" "July 23")
    ("14072400" "S. Christinae" "Christina, Virgin Martyr" "July 24")
    ("14072500" "S. Jacobi" "James the Greater, Apostle" "July 25")
    ("14072507" "Dominica post S. Jacobi" "Sunday after James the Greater" "")
    ("14072508" "S. Jacobi, infra octavas" "In week after James the Greater" "")
    ("14072510" "S. Christophori" "Christopher, Martyr" "July 25")
    ("14072520" "Tr. Germani, Juliani" "Moving of Germanus, Julianus relics" "Jul. 25")
    ("14072600" "Tr. S. Marcelli Par." "Moving of relics of Marcellus \(Paris\)" "July 26")
    ("14072610" "S. Annae" "Anne, Mother of Mary" "July 26")
    ("14072700" "S. Pantaleonis" "Pantaleon \(Panteleimon\), Martyr" "July 27")
    ("14072710" "SS. Sept. Dorm. Eph." "Seven Sleepers of Ephesus" "July 27")
    ("14072800" "SS. Nazarii, Celsi" "Nazarius and Celsus, Martyrs" "July 28")
    ("14072810" "S. Samsonis" "Samson, Bishop of Dol" "July 28")
    ("14072900" "S. Felicis" "Felix II, Pope" "July 29")
    ("14072910" "Octava S. Mariae Mag." "Octave of Mary Magdalene" "July 29")
    ("14072920" "SS. Simplicii et Soc." "Simplicius and Companions, Martyrs" "July 29")
    ("14072930" "S. Marthae" "Martha, Virgin" "July 29")
    ("14073000" "SS. Abdonis, Sennis" "Abdon and Sennen, Martyrs" "July 30")
    ("14073100" "S. Germani Antisiodorensis" "Germanus, Bishop of Auxerre" "July 31")
    ("14080100" "Vincula S. Petri" "Peter in Chains" "August 1")
    ("14080108" "Vincula S. Petri, infra octavas" "In week after Peter in Chains" "")
    ("14080110" "Octava S. Jacobi" "Octave of James the Greater" "August 1")
    ("14080120" "SS. Machabaeorum" "Holy Maccabees, Martyrs" "August 1")
    ("14080130" "S. Ethelwoldi" "Ethelwold, Bishop of Wincester" "August 1")
    ("14080140" "SS. Fidei et Soc." "Faith and Companions, Martyrs" "August 1")
    ("14080200" "S. Stephani, Pont." "Stephen I, Pope" "August 2")
    ("14080300" "Inventio S. Stephani" "Finding of Stephen, First Martyr" "August 3")
    ("14080500" "S. Afrae" "Afra, Martyr" "August 5")
    ("14080510" "S. Oswaldi, Reg." "Oswald, King of Northumbria" "August 5")
    ("14080520" "S. Mariae ad Nives" "Mary of the Snows" "August 5")
    ("14080600" "Transfiguratio Domini" "Transfiguration of Jesus" "August 6")
    ("14080610" "S. Sixti" "Sixtus and Companions, Martyrs" "August 6")
    ("14080700" "S. Donati" "Donatus, Bishop of Arezzo" "August 7")
    ("14080800" "SS. Cyriaci et Soc." "Cyriacus and Companions, Martyrs" "August 8")
    ("14080810" "S. Justini" "Justin, Child Martyred near Paris" "August 8")
    ("14080900" "S. Romani" "Romanus, Martyr" "August 9")
    ("14080910" "Vigilia S. Laurentii" "Eve of Feast for St. Laurence" "August 9")
    ("14081000" "S. Laurentii" "Laurence, Martyr" "August 10")
    ("14081008" "S. Laurentii, infra octavas" "In week after Laurence" "")
    ("14081100" "S. Tiburtii" "Tiburtius and Susanna, Martyrs" "August 11")
    ("14081110" "S. Gaugerici" "Gaugericus \(Gery\), Bishop" "August 11")
    ("14081117" "Dominica post S. Gaugerici" "Sunday after Gaugericus" "")
    ("14081118" "S. Gaugerici, infra octavas" "In week after Gaugericus" "")
    ("14081120" "De Corona Spinea" "Commemoration of the Crown of Thorns" "August 11")
    ("14081130" "S. Taurini" "Taurinus, Bishop of Evreux" "August 11")
    ("14081200" "S. Clarae" "Clare of Assisi, Foundress" "August 12")
    ("14081300" "S. Hippolyti" "Hippolytus, Martyr" "August 13")
    ("14081310" "S. Radegundis" "Radegund, Matron" "August 13")
    ("14081400" "S. Eusebii" "Eusebius of Rome" "August 14")
    ("14081410" "Vig. Assumpost Mariae" "Eve of Assumption of Mary" "August 14")
    ("14081500" "Assumptio Mariae" "Assumption of Mary" "August 15")
    ("14081507" "Dominica post Assumptionem" "Sunday after Assumption of Mary" "")
    ("14081508" "Assumptio Mariae, infra octavas" "In week after Assumption of Mary" "")
    ("14081600" "S. Arnulfi" "Arnulf, Bishop of Metz" "August 16")
    ("14081610" "S. Gemmae" "Gemma, Virgin" "August 16")
    ("14081700" "Octava S. Laurentii" "Octave of Laurence" "August 17")
    ("14081710" "Transl. S. Justinae" "Moving of Justina's relics" "August 17")
    ("14081800" "S. Agapiti" "Agapitus, Martyr" "August 18")
    ("14081808" "S. Agapiti, infra octavas" "In week after Agapitus" "")
    ("14081810" "Octava S. Gaugerici" "Octave of Gaugericus" "August 18")
    ("14081900" "S. Ludovici Toul." "Louis, Bishop of Toulouse" "August 19")
    ("14082000" "S. Philiberti" "Philibert, Abbot" "August 20")
    ("14082010" "S. Bernardi" "Bernard, Abbot and Doctor" "August 20")
    ("14082200" "S. Symphoriani" "Symphorian \(and Timothy\), Martyrs" "August 22")
    ("14082210" "Octava Assumptionis" "Octave of Assumption of Mary" "August 22")
    ("14082300" "Timothei,Apollinaris" "Timothy and Apollinaris, Martyrs" "August 23")
    ("14082400" "S. Bartholomaei" "Bartholomew, Apostle" "August 24")
    ("14082410" "S. Audoeni" "Audoenus \(Ouen\), Bishop of Rouen" "August 24")
    ("14082500" "S. Ludovici" "Louis IX, King of France" "August 25")
    ("14082510" "S. Hunegundis" "Hunegundis, Abbess" "August 25")
    ("14082520" "Octava S. Agapiti" "Octave of Agapitus" "August 25")
    ("14082800" "S. Augustini" "Augustine, Bishop and Doctor" "August 28")
    ("14082808" "S. Augustini, infra octavas" "In week after Augustine" "")
    ("14082810" "S. Juliani" "Julian of Brioude, Martyr" "August 28")
    ("14082820" "S. Rufi" "Rufus, Bishop" "August 28")
    ("14082830" "S. Hermetis" "Hermes, Martyr" "August 28")
    ("14082840" "S. Pelagii" "Pelagius, Martyr" "August 28")
    ("14082900" "Decoll. S. Jo. Bapt." "Beheading of John the Baptist" "August 29")
    ("14082910" "S. Sabinae" "Sabina, Martyr" "August 29")
    ("14082920" "S. Mederici" "Medericus \(Merry\), Abbot" "August 29")
    ("14083000" "SS. Felicis, Adaucti" "Felix and Adauctus, Martyrs" "August 30")
    ("14083100" "Transl. S. Hadulfi" "Moving of Hadulf's relics" "August 31")
    ("14083110" "S. Paulini" "Paulinus, Bishop of Trier" "August 31")
    ("14083120" "S. Cuthburgae" "Cuthberga, First Abbess of Wimborne" "August 31")
    ("14090100" "S. Aegidii" "Aegidius \(Giles\), Abbot" "September 1")
    ("14090110" "S. Lupi" "Lupus \(Leu\), Bishop of Sens" "September 1")
    ("14090120" "S. Prisci" "Priscus, Bishop of Capua" "September 1")
    ("14090130" "S. Verenae" "Verena, Virgin" "September 1")
    ("14090140" "SS. Duodecim Fratrum" "Twelve Brothers, Martyrs" "September 1")
    ("14090200" "S. Antonini" "Antoninus, Martyr" "September 2")
    ("14090300" "S. Remacli" "Remaclus, Bishop" "September 3")
    ("14090310" "Ordin. S. Gregorii" "Ordination of Gregory" "September 3")
    ("14090318" "Ordin. S. Gregorii, infra octavas" "In week after Gregory's Ordination" "")
    ("14090400" "Octava S. Augustini" "Octave of Augustine" "September 4")
    ("14090410" "Transl. S. Cuthberti" "Moving of Cuthbert's relics" "September 4")
    ("14090600" "S. Humberti" "Humbert, Abbot and Bishop" "September 6")
    ("14090610" "S. Magni" "Magnus, Apostle of Bavaria" "September 6")
    ("14090700" "S. Evurtii" "Evurtius \(Euvert\), Bishop" "September 7")
    ("14090710" "Vigilia Nativitatis Mariae" "Eve of Birthday of Mary" "September 7")
    ("14090720" "S. Chlodoaldi" "Chlodoaldus \(Cloud\), Frankish prince" "September 7")
    ("14090800" "Nativitas Mariae" "Birthday of Mary" "September 8")
    ("14090807" "Dominica post Nativitatis Mariae" "Sunday after Birthday of Mary" "")
    ("14090808" "Nativitas Mariae, infra octavas" "In week after Birthday of Mary" "")
    ("14090810" "Transl. S. Egwini" "Moving of Egwin's relics" "September 8")
    ("14090820" "S. Corbiniani" "Corbinianus, Abbot and Bishop" "September 8")
    ("14090900" "S. Gorgonii" "Gorgonius, Martyr" "September 9")
    ("14090910" "Tr. S. Kunegundis" "Moving of Cunegund's relics" "September 9")
    ("14090920" "S. Audomari" "Audomarus \(Omer\), Bishop" "September 9")
    ("14091000" "S. Adriani" "Adrian, Martyr" "September 10")
    ("14091100" "SS. Proti, Hiacinthi" "Protus and Hyacinth, Martyrs" "September 11")
    ("14091110" "SS. Felicis, Regulae" "Felix and Regula, Martyrs" "September 11")
    ("14091300" "S. Maurilii" "Maurilius, Bishop of Angers" "September 13")
    ("14091400" "Exaltatio S. Crucis" "Holy Cross Day \(Exaltation of the Cross\)" "September 14")
    ("14091408" "Exalt. S. Crucis, infra octavas" "In week after Holy Cross Day" "")
    ("14091500" "Reliquiarum" "Feast of Relics" "September 15")
    ("14091508" "Reliquiarum, infra octavas" "In week after Feast of Relics" "")
    ("14091510" "Octava Nativitatis Mariae" "Octave of Birthday of Mary" "September 15")
    ("14091520" "S. Aichardi" "Aichardus \(Achard, Aichadrus\), Abbot" "September 15")
    ("14091530" "S. Nicomedis" "Nicomedes, Martyr" "September 15")
    ("14091600" "SS.Cornelii,Cypriani" "Cornelius and Cyprian, Martyrs" "September 16")
    ("14091610" "S. Euphemiae" "Euphemia, Virgin and Martyr" "September 16")
    ("14091620" "SS.Luciae,Germiniani" "Lucy and Germinianus, Martyrs" "September 16")
    ("14091700" "S. Lamberti" "Lambert, Bishop of Maestricht" "September 17")
    ("14091708" "S. Lamberti, infra octavas" "In week after Lambert" "")
    ("14091900" "SS. Januarii et Soc." "Januarius and Companions, Martyrs" "September 19")
    ("14091910" "S. Materni" "Maternus, Bishop of Cologne" "September 19")
    ("14092000" "Elevatio S. Amandi" "Elevation of Amand's relics" "September 20")
    ("14092100" "S. Matthaei" "Matthew, Apostle and Evangelist" "September 21")
    ("14092108" "S. Matthaei, infra octavas" "In week after Matthew" "")
    ("14092200" "S. Mauritii" "Maurice and Companions, Martyrs" "September 22")
    ("14092210" "S. Emmerami" "Emmeramus, Bishop" "September 22")
    ("14092300" "S. Theclae" "Thecla of Iconium, Virgin Martyr" "September 23")
    ("14092400" "Elevat. S. Gaugerici" "Elevation of Gaugericus's relics" "September 24")
    ("14092410" "Octava S. Lamberti" "Octave of Lambert" "September 24")
    ("14092420" "S. Ruperti" "Rupert \(Rubert\), Bishop" "September 24")
    ("14092500" "S. Firmini" "Firminus, Bishop Martyr" "September 25")
    ("14092508" "S. Firmini, infra octavas" "In week after Firminus" "")
    ("14092510" "S. Cleophae" "Cleophas, father of James the Less" "September 25")
    ("14092600" "S. Justinae" "Justina and Cyprian, Martyrs" "September 26")
    ("14092608" "S. Justinae, infra octavas" "In week after Justina and Cyprian" "")
    ("14092700" "SS. Cosmae, Damiani" "Cosmas and Damian, Martyrs" "September 27")
    ("14092800" "S. Wenceslai" "Wenceslaus of Bohemia, Martyr" "September 28")
    ("14092900" "S. Michaelis" "Michael the Archangel \(Michaelmas\)" "September 29")
    ("14093000" "S. Hieronimi" "Jerome, Doctor" "September 30")
    ("14093008" "S. Hieronimi, infra octavas" "In week after Jerome" "")
    ("14100100" "S. Remigii" "Remigius \(Remi\), Bishop of Rheims" "October 1")
    ("14100110" "SS. Germani, Vedasti" "Germanus and Vedastus, Martyrs" "October 1")
    ("14100120" "S. Melori" "Melorus \(Melar, Mylor\), Martyr" "October 1")
    ("14100200" "S. Leodegarii" "Leodegarius \(Leger\), Bishop Martyr" "October 2")
    ("14100210" "S. Sereni" "Serenus, Confessor" "October 2")
    ("14100300" "Octava S. Justinae" "Octave of Justina and Cyprian" "October 3")
    ("14100400" "S. Francisci" "Francis of Assisi" "October 4")
    ("14100408" "S. Francisci, infra octavas" "In week after Francis of Assisi" "")
    ("14100410" "S. Aureae" "Aurea, Abbess in Paris" "October 4")
    ("14100500" "Transl. S. Vedasti" "Moving of Vaast's relics" "October 5")
    ("14100507" "Dominica post Translationem S.Vedasti" "Sunday after Vaast's Translation" "")
    ("14100508" "Transl. S. Vedasti, infra octavas" "In week after Vaast's Translation" "")
    ("14100600" "S. Fidis" "Faith, Virgin Martyr" "October 6")
    ("14100700" "S. Marci, Pont." "Mark, Pope" "October 7")
    ("14100710" "SS.Marcelli,Apuleii" "Marcellus and Apulejus, Martyrs" "October 7")
    ("14100720" "Transl. S. Wolfgangi" "Moving of Wolfgang's relics" "October 7")
    ("14100800" "S. Ragenfredis" "Ragenfredis, Cannoness" "October 8")
    ("14100810" "S. Benedictae" "Benedicta, Virgin Martyr" "October 8")
    ("14100820" "SS. Sergii, Bacchi" "Sergius and Bacchus, Martyrs" "October 8")
    ("14100830" "Transl. S. Oswaldi" "Moving of Oswald's relics" "October 8")
    ("14100838" "Transl. S. Oswaldi, infra octavas" "In week after Oswald's Translation" "")
    ("14100900" "S. Dionysii" "Denis \(Dionysius\), Bishop of Paris" "October 9")
    ("14100908" "S. Dionysii, infra octavas" "In week after Denis, Bishop of Paris" "")
    ("14100910" "S. Gisleni" "Gislenus \(Ghislain\), Abbot" "October 9")
    ("14100920" "S. Richarii" "Richarius \(Riquier\), Abbot" "October 9")
    ("14100930" "SS. Patriarcharum" "Abraham, Isaac and Jacob" "October 9")
    ("14101000" "SS. Gereonis et Soc." "Gereon and Companions, Martyrs" "October 10")
    ("14101010" "S. Paulini Ebor." "Paulinus, Archbishop of York" "October 10")
    ("14101018" "S. Paulini Ebor., infra octavas" "In week after Paulinus of York" "")
    ("14101100" "S. Venantii" "Venantius, Hermit" "October 11")
    ("14101110" "S. Probi" "Probus and Tarachus, Martyrs" "October 11")
    ("14101120" "Transl. S. Augustini" "Moving of Augustine's relics" "October 11")
    ("14101130" "SS. Nigasii et Soc." "Nicasius of Rouen, alleged Bishop of Rouen" "October 11")
    ("14101200" "S. Opilii" "Opilius, Deacon" "October 12")
    ("14101210" "Octava Tr. S. Vedasti" "Octave of Vaast's Translation" "October 12")
    ("14101220" "S. Maximiliani" "Maximilian, Bishop of Lorch" "October 12")
    ("14101230" "S. Wilfridi" "Wilfrid, Archbishop of York" "October 12")
    ("14101300" "S. Geraldi" "Gerald of Aurillac" "October 13")
    ("14101310" "S. Donatiani" "Donatianus, Bishop of Reims" "October 13")
    ("14101320" "S. Colomanni" "Coloman, Martyr" "October 13")
    ("14101330" "Transl. S. Edwardi" "Moving of Edward's relics" "October 13")
    ("14101400" "S. Callisti" "Callistus \(Calixtus\) I, Pope" "October 14")
    ("14101600" "S. Galli" "Gall, Hermit" "October 16")
    ("14101610" "Octava S. Dionysii" "Octave of Denis, Bishop of Paris" "October 16")
    ("14101620" "SS. Luciani et Soc." "Lucianus and Companions, Martyrs" "October 16")
    ("14101630" "Ded. Mont. S.Michaelis" "Dedication of Mont-Saint-Michel" "October 16")
    ("14101640" "S. Hedwigis" "Hedwig, Matron and Duchess of Silesia" "October 16")
    ("14101800" "S. Lucae" "Luke, Evangelist" "October 18")
    ("14101808" "S. Lucae, infra octavas" "In week after Luke" "")
    ("14101810" "S. Justi" "Justus of Beauvais, Martyr" "October 18")
    ("14101820" "S. Herblandi" "Hermeland, Abbot of Aindre \(Nantes\)" "October 18")
    ("14101900" "S. Amati" "Amatus, Bishop of Sens" "October 19")
    ("14101910" "S. Januarii" "Januarius" "October 19")
    ("14101920" "S. Petri Alcan." "Peter of Alcantara, Founder" "October 19")
    ("14102100" "SS. XI milia Virg." "11,000 Virgin Martyrs of Cologne" "October 21")
    ("14102110" "S. Ursulae" "Ursula, Virgin Martyr" "October 21")
    ("14102120" "S. Hilarionis" "Hilarion, Abbot" "October 21")
    ("14102300" "S. Severini, Epi." "Severinus, Confessor &amp; Bishop of Cologne" "October 23")
    ("14102400" "S. Maglorii" "Magloire \(Maelor\), Bishop of Dol" "October 24")
    ("14102500" "Crispini,Crispiniani" "Crispin and Crispinian, Martyrs" "October 25")
    ("14102510" "S. Miniatis" "Minias, Martyr" "October 25")
    ("14102520" "S. Lupi Bajocensis" "Lupus, Bishop of Bayeux" "October 25")
    ("14102600" "Ordinatio S. Amandi" "Ordination of Amandus \(Amand\)" "October 26")
    ("14102800" "SS. Simonis, Judae" "Simon, Jude \(Thaddeus\), Apostles" "October 28")
    ("14102900" "S. Narcissi" "Narcissus, Bishop of Jerusalem" "October 29")
    ("14103000" "S. Lucani" "Lucanus of Gascony, Martyr" "October 30")
    ("14103100" "S. Quintini" "Quintinus \(Quentin\), Martyr" "October 31")
    ("14103110" "S. Foliani" "Foillan \(Folianus\), Abbot" "October 31")
    ("14103120" "Vig. Om. Sanctorum" "Eve of All Saints' Day" "October 31")
    ("14103130" "S. Wolfgangi" "Wolfgangus, Bishop of Regensburg" "October 31")
    ("14110100" "Omnium Sanctorum" "All Saints' Day" "November 1")
    ("14110107" "Dominica post Omnium Sanctorum" "Sunday after All Saints' Day" "")
    ("14110108" "Infra Octavis Omnium Sanctorum" "In week after All Saints' Day" "")
    ("14110110" "S. Ulgani" "Vulgan, Hermit" "November 1")
    ("14110120" "S. Vigoris" "Vigor, Bishop of Bayeux" "November 1")
    ("14110130" "SS. Caesarii,Juliani" "Caesarius and Julian, Martyrs" "November 1")
    ("14110200" "S. Eustachii" "Eustachius \(Eustace\), Martyr" "November 2")
    ("14110300" "S. Pirmini" "Pirminus, Abbot and Bishop" "November 3")
    ("14110310" "S. Marcelli Parisi." "Marcellus, Bishop of Paris" "November 3")
    ("14110318" "S. Marcelli Par., infra octavas" "In week after Marcellus of Paris" "")
    ("14110320" "S. Wenaili" "Guenael, Abbot of Landevennec" "November 3")
    ("14110600" "S. Vinoci" "Winnoc \(Vinocus\), Abbot" "November 6")
    ("14110610" "S. Leonardi" "Leonard, Hermit" "November 6")
    ("14110700" "S. Willibrordi" "Willibrord, Bishop of Utrecht" "November 7")
    ("14110800" "SS.Quat.Coronatorum" "The Four Crowned Ones, Martyrs" "November 8")
    ("14110810" "Octava Omnium Sanctorum" "Octave of All Saints' Day" "November 8")
    ("14110900" "De Imagine Domini" "The Icon of our Lord Saviour" "November 9")
    ("14110910" "S. Theodori Tiro" "Theodore Tiro, Martyr" "November 9")
    ("14110920" "S. Vitoni" "Vitonus \(Vanne\), Bishop of Verdun" "November 9")
    ("14110930" "S. Maturini" "Maturin, Priest of Larchant \(Sens\)" "November 9")
    ("14110940" "Dedicatio S. Salvatoris" "Dedication of Saint Saviour's" "November 9")
    ("14111000" "Octava S. Marcelli Parisiensis" "Octave of Marcellus, Bishop of Paris" "November 10")
    ("14111100" "S. Martini" "Martin, Bishop of Tours" "November 11")
    ("14111107" "Dominica post S. Martini" "Sunday after Martin" "")
    ("14111108" "S. Martini, infra octavas" "In week after Martin" "")
    ("14111110" "S. Mennae" "Mennas, Martyr" "November 11")
    ("14111200" "S. Lebuini" "Lebwin \(Lebuin, Liafwin, Leafwine\), Confessor" "November 12")
    ("14111300" "S. Bricii" "Brice, Bishop of Tours" "November 13")
    ("14111310" "Inventio S. Antonini" "Finding of Antoninus's relics" "November 13")
    ("14111320" "S. Maxellendis" "Maxellendis, Virgin Martyr" "November 13")
    ("14111330" "S. Genulfi" "Genulf \(Gendulf, Genou\), Bishop" "November 13")
    ("14111500" "S. Eugenii" "Eugene, Martyr, Disciple of St. Denis" "November 15")
    ("14111510" "S. Machuti" "Maclovius \(Malo\), Bishop of Aleth" "November 15")
    ("14111520" "S. Leopoldi" "Leopold, Prince of Austria" "November 15")
    ("14111600" "S. Othmari" "Othmar \(Audemar\), Abbot" "November 16")
    ("14111700" "S. Gregorii Thauma." "Gregory the Wonderworker, Bishop" "November 17")
    ("14111710" "S. Aniani" "Anianus \(Aignan\), Bishop of Orleans" "November 17")
    ("14111800" "Octava S. Martini" "Octave of Martin" "November 18")
    ("14111810" "S. Romani Antiochiae" "Romanus of Antioch, Martyr" "November 18")
    ("14111900" "S. Elisabeth Hung." "Elizabeth of Hungary, Widow" "November 19")
    ("14111908" "S. Elisabeth Hung., infra octavas" "In week after Elizabeth of Hungary" "")
    ("14112000" "S. Edmundi" "Edmund, King and Martyr" "November 20")
    ("14112100" "Praesentatio Mariae" "Presentation of Mary" "November 21")
    ("14112200" "S. Caeciliae" "Cecilia \(Cecily\), Virgin Martyr" "November 22")
    ("14112208" "S. Caeciliae, infra octavas" "In week after Cecilia" "")
    ("14112300" "S. Clementis" "Clement I, Pope and Martyr" "November 23")
    ("14112308" "S. Clementis, infra octavas" "In week after Clement" "")
    ("14112310" "S. Felicitatis" "Felicitatis, Matron and Martyr" "November 23")
    ("14112320" "S. Trudonis" "Trudo \(Trond\)" "November 23")
    ("14112330" "S. Columbani" "Columbanus \(Columban\), Abbot" "November 23")
    ("14112400" "S. Chrysogoni" "Chrysogonus, Martyr" "November 24")
    ("14112410" "S. Severini" "Severinus, Monk, Teacher of St. Cloud" "November 24")
    ("14112500" "S. Catharinae" "Catherine of Alexandria, Martyr" "November 25")
    ("14112600" "S. Lini" "Linus, Bishop of Rome" "November 26")
    ("14112610" "Mirac. S. Genovefae" "Commemoration of Genevieve's Miracle" "November 26")
    ("14112620" "S. Conradi" "Conrad, Bishop of Constance" "November 26")
    ("14112900" "S. Saturnini" "Saturninus, Martyr Bishop of Toulouse" "November 29")
    ("14112910" "SS.Chrysanthi,Dariae" "Chrysanthus, Daria, Maurus, Martyrs" "November 29")
    ("14113000" "S. Andreae" "Andrew, Apostle" "November 30")
    ("14113008" "S. Andreae, infra octavas" "In week after Andrew" "")
    ("14120100" "S. Eligii" "Eligius \(Eloi\), Bishop of Noyon" "December 1")
    ("14120400" "S. Barbarae" "Barbara, Virgin Martyr" "December 4")
    ("14120410" "Suscept. Reliquiarum" "Feast of Relics \(Notre Dame, Paris\)" "December 4")
    ("14120500" "S. Sabae" "Sabas, Abbot" "December 5")
    ("14120600" "S. Nicolai" "Nicholas of Bari, Bishop of Myra" "December 6")
    ("14120608" "S. Nicolai, infra octavas" "In week after Nicholas" "")
    ("14120610" "Octava S. Saturnini" "Octave of Saturninus" "December 6")
    ("14120700" "S. Victoris" "Victor, Bishop of Piacenza" "December 7")
    ("14120710" "Octava S. Andreae" "Octave of Andrew" "December 7")
    ("14120720" "Transl. S. Baboleni" "Moving of Babolenus' relics" "December 7")
    ("14120800" "Conceptio Mariae" "Immaculate Conception of Mary" "December 8")
    ("14120900" "S. Syri" "Syrus" "December 9")
    ("14121000" "S. Gabrielis" "Gabriel" "December 10")
    ("14121010" "S. Valeriae" "Valeria" "December 10")
    ("14121100" "S. Damasi" "Damasus, Pope" "December 11")
    ("14121110" "SS.Fusciani,Gentiani" "Fuscian and Gentian, Martyrs" "December 11")
    ("14121300" "S. Luciae" "Lucy \(Lucia\), Virgin Martyr" "December 13")
    ("14121308" "S. Luciae, infra octavas" "In week after Lucy" "")
    ("14121310" "S. Aubertii" "Aubert \(Aubertus\), Bishop of Cambrai" "December 13")
    ("14121320" "Octava S. Nicolai" "Octave of Nicholas" "December 13")
    ("14121330" "S. Judoci" "Judoc, Prince and Hermit" "December 13")
    ("14121340" "S. Odiliae" "Odilia \(Ottilia\), Abbess" "December 13")
    ("14121350" "SS.Eustratii et Soc." "Eustratius et al, Martyrs" "December 13")
    ("14121400" "S. Nicasii" "Nicasius, Bishop Martyr of Rheims" "December 14")
    ("14121410" "Relatio S. Martini" "Return of Martin's relics" "December 14")
    ("14121700" "S. Lazari" "Lazarus of Bethany, Bishop of Marseilles" "December 17")
    ("14121800" "S. Gatiani" "Gatian, Bishop of Tours" "December 18")
    ("14122100" "S. Thomae Apost." "Thomas, Apostle" "December 21")
    ("14122300" "S. Victoriae" "Victoria and Anatolia, Virgin Martyrs" "December 23")
    ("14122400" "S. Gregorii, Mart." "Gregory of Spoleto, Martyr" "December 24")
    ("14122900" "S. Thomae Cant." "Thomas Becket, Archbishop of Canterbury" "December 29")
    ("14122908" "S. Thomae Cant., infra octavas" "In week after Thomas Becket" "")
    ("14122910" "S. Trophimi" "Trophimus, Bishop of Arles" "December 29")
    ("14123000" "S. Egwini" "Egwin, Bishop of Worcester" "December 30")
    ("14123008" "S. Egwini, infra octavas" "In week after Egwin" "")
    ("14123010" "S. Perpetui" "Perpetuus, Bishop of Tours" "December 30")
    ("14123100" "S. Silvestri" "Silvester I, Pope" "December 31")
    ("14123110" "S. Columbae" "Columba of Sens, Virgin Martyr" "December 31")
    ("15000000" "Ad Suffragium" "Memorial chants" "")
    ("15001000" "Suffragia pro Pace" "Memorial chants for peace" "")
    ("15002000" "SS.Oswaldi,Wulstani" "Memorial chants for Oswald, Wulfstan" "")
    ("15003000" "Suffragia pro Penitent." "Memorial chants for penitence" "")
    ("15004000" "Suffragia Apostolorum" "Memorial chants for Apostles" "")
    ("15005000" "Suffragia Confessorum" "Memorial chants for Confessors" "")
    ("15006080" "Suffragia un. Mart. in tempore Paschae" "Memorial chants for one Martyr, in Eastertide" "")
    ("15007000" "Commune BMV" "Common chants for Mary" "")
    ("15008000" "De BMV" "Votive Office for Mary" "")
    ("15008080" "De BMV in tempore Paschae" "Votive Office for Mary, in Eastertide" "")
    ("15010300" "Suffragia S. Genovefae" "Memorial chants for Genevieve" "")
    ("15020600" "Suffragia S. Vedasti" "Memorial chants for Vaast" "")
    ("15022500" "Suffragia S. Walburgae" "Memorial chants for Walburga" "")
    ("15030100" "Suffragia S. David" "Memorial chants for David" "")
    ("15032100" "Suffragia S. Benedicti" "Memorial chants for Benedict" "")
    ("15050300" "Suffragia S. Crucis" "Memorial chants for the Holy Cross" "")
    ("15050380" "Suffragia S. Crucis in tempore Paschae" "Memorial chants for Holy Cross, Eastertide" "")
    ("15062400" "Suffragia S. Jo. Bapt." "Memorial chants for John the Baptist" "")
    ("15062410" "SuffragiaS.Jo.Bapt. Adventus" "Memorials, John the Baptist, Advent" "")
    ("15062430" "Memoriae Sancti Joannis Baptistae in tempore Nativitatis" "Memorials, John the Baptist, Christmas" "")
    ("15062480" "SuffragiaS.Jo.Bapt. in tempore Paschae" "Memorials, John the Bapt., Eastertide" "")
    ("15062900" "Suffragia SS.Petri,Pauli" "Memorial chants for Peter and Paul" "")
    ("15071200" "Suffragia S. Hermagorae" "Memorial chants for Hermagoras" "")
    ("15081500" "Suffragia S. Mariae" "Memorial chants for Mary" "")
    ("15081501" "Recollectio Mariae" "Recollection of Feasts of Mary" "")
    ("15081510" "Memoriae S. Mariae infra Adventus" "Memorial chants for Mary, Advent" "")
    ("15081530" "Memoriae S. Mariae in tempore Nativitatis" "Memorial chants for Mary, Christmas" "")
    ("15081580" "Suffragia S. Mariae in tempore Paschae" "Memorial chants for Mary, Eastertide" "")
    ("15091400" "Suffragia Exalt. S. Cru." "Memorials for Exaltation of Cross" "")
    ("15091700" "Suffragia S. Lamberti" "Memorial chants for Lambert" "")
    ("15092200" "Suffragia S. Mauritii" "Memorial chants for Maurice" "")
    ("15092600" "Suffragia S. Justinae" "Memorial chants for Justina" "")
    ("15092680" "Suffragia S. Justinae in tempore Paschae" "Memorial chants for Justina, Easter" "")
    ("15092900" "Suffragia S. Michaelis" "Memorial chants for Michael" "")
    ("15110100" "Suffragia Om. Sanctorum" "Memorial chants for All Saints" "")
    ("15110110" "Suffragia Om. Sanct. Adv" "Memorials for All Saints, Advent" "")
    ("15110130" "Suffragia Om. Sanct. Nat" "Memorials for All Saints, Christmas" "")
    ("15110180" "Suffragia Om. Sanct. in tempore Paschae" "Memorials for All Saints, Eastertide" "")
    ("15110300" "Suffragia S. Marcelli Par." "Memorials for Marcellus of Paris" "")
    ("15111100" "Suffragia S. Martini" "Memorial chants for Martin of Tours" "")
    ("15120400" "Suffragia Reliquiarum" "Memorial chants for Relics" "")
    ("15122600" "Suffragia S. Stephani" "Memorial chants for Stephan" "")
    ("17002000" "Translatio S. Christofori" "Moving of Christopher's relics" "")
    )
  "An alist of day-codes with Latin and English descriptions, and \(where appropriate\) the modern calendar date")

;; (defvar lect-nums
;;   '(
;;     ("1" "j.")
;;     ("2" "ij.")
;;     ("3" "iij.")
;;     ("4" "iiij.")
;;     ("5" "v.")
;;     ("6" "vj.")
;;     ("7" "vij.")
;;     ("8" "viij.")
;;     ("9" "ix.")
;;     ("10" "x.")
;;     ("11" "xj.")
;;     ("12" "xij.")
;;     )
;;   "An alist of Arabic and corresponding Roman numerals for numbering lections")

(defvar lection-nums
  '(
    ("1" "j" "prima")
    ("2" "ij" "secunda")
    ("3" "iij" "tertia")
    ("4" "iiij" "quarta")
    ("5" "v" "quinta")
    ("6" "vj" "sexta")
    ("7" "vij" "septima")
    ("8" "viij" "octava")
    ("9" "ix" "nona")
    ("10" "x" "decima")
    ("11" "xj" "undecima")
    ("12" "xij" "duodecima")
    )
  "An alist of Arabic and corresponding Roman numerals for numbering lections")

(defvar ferias
  '(
    (2 "secunda" "Monday")
    (3 "tertia" "Tuesday")
    (4 "quarta" "Wednesday")
    (5 "quinta" "Thursday")
    (6 "sexta" "Friday")
    (7 "Sabbato" "Saturday")
    )
  "An alist of feria names and numbers.")

(defvar nocturns
  '(
    ("1" "primo" "First")
    ("2" "secundo" "Second")
    ("3" "tertio" "Third")
    )
  "An alist of numbers for nocturns.")

;;}}}-------------------------------------------------------------------------

;;{{{ Checking and analysis of repository items:

(defvar *correct-wits*
  (split-string "CAO-C CAO-G CAO-B CAO-E CAO-M CAO-V CAO-H CAO-R CAO-D CAO-F CAO-S CAO-L Bat Nch Abn Hyd Wor Ely Cht Wcb Alb2 Pet Evm Mch Cld Glo Fec-B2")
  "A list of Cursus-project manuscript sigla recognised as valid.")

(defvar *cao-wits*
  (split-string "CAO-C CAO-G CAO-B CAO-E CAO-M CAO-V CAO-H CAO-R CAO-D CAO-F CAO-S CAO-L")
  "A list of sigla of CAO sources.")

(defvar *cao-rom-wits*
  (split-string "CAO-C CAO-G CAO-B CAO-E CAO-M CAO-V")
  "A list of sigla of CAO 'Roman' sources.")

(defvar *cao-mon-wits*
  (split-string "CAO-H CAO-R CAO-D CAO-F CAO-S CAO-L")
  "A list of sigla of CAO 'monastic' sources.")

(defvar *insular-wits*
  (split-string "Bat Nch Abn Hyd Wor Ely Cht Wcb Alb2 Pet Evm Mch Cld Glo")
  "A list of sigla of insular sources.")

(defvar *norman-wits*
  (split-string "Fec-B1 Fec-B2 Fec-A Fec-O")
  "A list of sigla of Norman sources.")

(defun cursus-wit-test ()
  "Cursus project editing/testing function.

Main (called) function for generating report on values of attribute
'wit' in a single repository item.

This function runs a number of others, which together write a
temporary file *Wit Report* with the following information: 

1. Any sigla given as the value of a 'wit' attribute which are not
recognised as correct
\n2. Discrepancy between the 'wit' values contained within an
<app> and those given in the containing element \(rBody, rVerse, &c\)
\n3. Duplication of wit values within any one set of values
\n4. Duplication of wit values in the <rdg> tags contained within an
<app> element
\n5. The existence within a respond of a <vBody> element for a witness
not shown as having a <rBody>
\n6. The existence of a <rep> element for a witness not shown as
having a <vBody>
\n7. Identical content in two <rdg> elements within the same <app>."

  (interactive)
  (setq r-num 0
        a-num 0
        v-num 0
        p-num 0
        *app-wits* nil)
  (save-excursion
    (save-restriction
      (with-output-to-temp-buffer "*Wit Report*"
        (cursus-pos-inside-item)
        (cursus-prepare-item-for-test)
        (while
            (re-search-forward "<\\(rBody\\|aBody\\|vBody\\|pBody\\)" nil t)
          (setq body-type (regexp-quote (match-string 1)))
          (cond
            ((string= body-type "rBody")
             (setq r-num (+ r-num 1)))
            ((string= body-type "aBody")
             (setq a-num (+ a-num 1)))
            ((string= body-type "vBody")
             (setq v-num (+ v-num 1))))
          (setq body-beg (point))
          (cursus-get-container-wits)
          (cursus-test-app-wits))
        (if
         (string= item-type "respond")
         (cursus-collate-wits))
        (widen)
        (princ (format "\nChecking completed on %s %s" item-type id-num))))))

(defun cursus-get-container-wits ()
  "Cursus editing/checking function.

Gets the values of the attribute *wits* of the current body ---
rBody, aBody, vBody, pBody --- and transforms them into a Lisp list for
subsequent processing.  Reports on errors in these container wits."
  (setq *container-wits* nil)
  (save-excursion
    (re-search-forward "</\\(rBody\\|aBody\\|vBody\\|pBody\\)" nil t)
    (setq body-end (point))
    (goto-char body-beg)
    (re-search-forward "wit=\"\\([- A-Za-z0-9]+[^\"]\\)" nil t)
    (setq *container-wits* (split-string (regexp-quote (match-string 1))))
    (cond
      ((string-equal body-type "rBody")
       (princ (format "Looking at %s no.%s ...\n" body-type r-num)))
      ((string-equal body-type "aBody")
       (princ (format "Looking at %s no.%s ...\n" body-type a-num)))
      ((string-equal body-type "vBody")
       (princ (format "Looking at %s no.%s ...\n" body-type v-num)))
      ((string-equal body-type "pBody")
       (princ (format "Looking at %s no.%s ...\n" body-type p-num))))
    (if
     (setq rogue-wit (set-difference *container-wits* *correct-wits* :test 'string=))
     (princ (format "... ERROR! %s in the container wits not recognised as correct sigl.\n" rogue-wit)))
    (cursus-test-dup-wit *container-wits*)
    (if 
     dup-list
     (princ (format "... ERROR! %s duplicated in container wits\n" dup-list)))
    (goto-char body-beg)))

(defun cursus-prepare-item-for-test ()
  "Cursus project editing/testing function.

Part of routine to check values of 'wit' attributes in repository
item.  Sets some variables for the reporting and narrows to the item
being checked."
  (re-search-backward "<\\(res\\|ant\\|prayer\\) id=\"\\([a-z][0-9]+\\)" nil t)
  (cond
    ((string= (match-string 1) "res")
     (setq item-type 'respond))
    ((string= (match-string 1) "ant")
     (setq item-type 'antiphon))
    ((string= (match-string 1) "prayer")
     (setq item-type 'prayer)))
  (setq id-num (regexp-quote (match-string 2)))
  (princ (format "Report on wit values in %s %s\n\n" item-type id-num))
  (setq item-beg (point))
  (re-search-forward "</\\(res\\|ant\\|prayer\\)" nil t)
  (setq item-end (point))
  (goto-char item-beg)
  ;; we are left at the very beginning of <res or whatever 
  (narrow-to-region item-beg item-end))

(defun cursus-collate-wits ()
  "Cursus project editing/testing function.

Part of routine to check values of 'wit' attributes in repository
item.  If you're in a respond, checks and reports on the relationship
between wits given for rBody and vBody elements."
  (save-excursion
    (goto-char item-beg)
    ;; initiate the vars and gather the evidence:
    (setq *rbody-wits* nil
          *vbody-wits* nil
          *rep-wits* nil)
    (save-excursion
      (while
          (search-forward "<rBody" nil t)
        (re-search-forward "wit=\"\\([- A-Za-z0-9]+[^\"]\\)" nil t)
        (setq *rbody-wits* (append (split-string (regexp-quote (match-string 1))) *rbody-wits*))))
    (save-excursion
      (while
          (search-forward "<vBody" nil t)
        (re-search-forward "wit=\"\\([- A-Za-z0-9]+[^\"]\\)" nil t)
        (setq *vbody-wits* (append (split-string (regexp-quote (match-string 1))) *vbody-wits*))))
    (save-excursion
      (while
          (search-forward "<rep" nil t)
        (re-search-forward "wit=\"\\([- A-Za-z0-9]+[^\"]\\)" nil t)
        (setq *rep-wits* (append (split-string (regexp-quote (match-string 1))) *rep-wits*)))))
    ;; analyse the evidence and report back:
    (if
     (setq v-error (set-difference *vbody-wits* *rbody-wits* :test 'string=))
     (princ (format "\n---------------\nERROR! vBody shown for %s but no rBody given\n" v-error)))
    (if
     (setq r-error (set-difference *rep-wits* *vbody-wits* :test #'string=))
     (princ (format "\nERROR! rep shown for %s but no vBody given\n" r-error)))
    (if
     (setq advice (set-difference *rbody-wits* *vbody-wits* :test 'string=))
     (princ (format "\nNB: no vBody given for %s\n" advice))))

(defun cursus-test-app-wits ()
  "Cursus project editing/testing function.

Part of routine to check values of 'wit' attributes in repository
item.  Tests the validity of wit attributes within each <app> and also
reports on whether two <rdg> elements have the same content."
  (setq app-num 1)
  (save-excursion
    (while
        (search-forward "<app>" body-end t)
      (setq app-beg (point))
      (search-forward "</app>" nil t)
      (setq app-end (point))
      (goto-char app-beg)
      ;; accumulate the rdg-wits of the <app> into a list:
      (while
          ;; NBB it is possible that more than one space has
          ;; insinuated itself between 'rdg' and 'wit' in the tag, so
          ;; allow for this in the regexp:
          (re-search-forward "<rdg +wit=\"\\([- A-Za-z0-9]+[^\"]\\)" app-end t)
        (setq *app-wits* (append (split-string (regexp-quote (match-string 1))) *app-wits*)))
      ;; test and write report:
      (cursus-test-dup-wit *app-wits*)
      (if
       dup-list
       (princ (format "... ERROR! %s duplicated in app no.%s\n" dup-list app-num)))
      (if
       (setq error (set-difference *app-wits* *correct-wits* :test 'string=))
       (princ (format "... ERROR! app no.%s has %s not recognised as correct sigl.\n" app-num error)))
      (if
       (setq error (set-difference *app-wits* *container-wits* :test 'string=))
       (princ (format "... ERROR! app no.%s has %s not among container wits\n" app-num error)))
      (if
       (setq error (set-difference *container-wits* *app-wits* :test 'string=))
       (princ (format "... ERROR! container has %s not among app no.%s wits\n" error app-num)))
      ;; Test for duplication of content between <rdg> tags (this is
      ;; the tricky bit!):
      (goto-char app-beg)
      (setq content-error nil)
      (while
          (re-search-forward "<rdg +wit=\"[- A-Za-z0-9]+\">\\(.*\\)</rdg>" app-end t)
        ;; If we split the string on just a space (the default of
        ;; 'split-string') we will find that two rdgs will fail to
        ;; throw an error (i.e. they will not show as being the same)
        ;; even if they differ by only e.g. <corr>foo </corr> against
        ;; <corr> foo</corr> (note the spaces).  The workaround is to
        ;; split on the tag-delimiters (< and >) as well.  The snag
        ;; then is that the resulting lists will probably contain
        ;; 'random' empty list-items, so we get rid of those with
        ;; 'remove'.  Of course that leaves the problem of two
        ;; readings which differ only by e.g. <corr resp="AB"> as
        ;; opposed to <corr resp="CD">, which will register as
        ;; different even if in other respects they are the same: but
        ;; that's life! :
        (setq rdg-content (remove "" (split-string (match-string 1) "[ <>]")))
        ;; We've got the content as a variable.  Now pause where we
        ;; are and test it against its successors in the app:
        (save-excursion
          (while
              (re-search-forward "<rdg +wit=\"[- A-Za-z0-9]+\">\\(.*\\)</rdg>" app-end t)
            (setq next-rdg-content (remove "" (split-string (match-string 1) "[ <>]")))
            ;; Now do an equality test on every rdg found --- we want
            ;; the find equal _lists_, not equal _sets_, to allow for
            ;; e.g. simple transposition of words; so plain 'equal'
            ;; will do:
            (if
             (equal rdg-content next-rdg-content)
             ;;  NB we only need to find one error to justify a
             ;; message, so we can do it by setting a variable to t:
             (setq content-error t))
            )))
      ;; That's the end of the test. Now do any report:
      (if
       content-error
       (princ (format "... ERROR! duplicated rdg content in app no.%s\n" app-num)))
      ;; Reset the variables for the next time round:
      (setq app-num (+ app-num 1)
            *app-wits* nil
            content-error nil)
      )))

(defun cursus-test-dup-wit (list)
  "Cursus project editing/testing function.

Part of routine to check values of 'wit' attributes in repository
item.  Checks if a Ms siglum appears more than once inside a set of
'wit' values."
  (setq dup-list nil)
  ;; (TODO: much more stylish to use 'dolist'!)
  (while list
    (if
     (member (car list) (cdr list))
     (setq dup-list (cons (car list) dup-list)))
    (setq list (cdr list))))

;;}}}---------------------------------------------------------------------------

;;{{{ Various subsidiary functions:

(defun add-one-to-stringnum (x)
  "Shorthand for adding 1 to a number given as a string."
  (number-to-string (+ (string-to-number x) 1)))

(defvar cursus-saved-position 0
  "Saved place")
(make-variable-buffer-local 'cursus-saved-position)

(defun cursus-mark ()           
  "Mark position in buffer"
  (interactive)
  (setq cursus-saved-position (point-marker)))

(defun cursus-find ()           
  "Return to saved place in buffer"
  (interactive)
  (goto-char cursus-saved-position))

(defun cursus-unique-lines ()
  "Delete adjacent duplicate lines in the buffer from point to
end-of-buffer, leaving only the unique lines."
  (interactive)
  (let (last-line this-line)
    (setq last-line (get-next-line))
    (while last-line
      (setq this-line (get-next-line))
      (if (equal last-line this-line)
          (kill-line -1))
      (setq last-line this-line))))

(defun get-next-line ()
  "Return the next line in the buffer, leaving point following it.
Nil is returned at end-of-buffer."
  (let (start)
    (beginning-of-line)
    (setq start (point))
    (forward-line 1)
    (if (equal start (point))
        nil
      (buffer-substring start (point)))))

;; taken from tei-emacs-init.el:
(defun insert-date-time()
  (interactive)
  (insert (format-time-string "[%Y-%m-%dT%T%z]" (current-time))))

(defun cursus-record-next-physical-element ()
  "Cursus project editing function.

When you are anywhere inside an element - from < of the opening tag to
> of the closing one - this function stores as variable 'next-element'
the next-encountered tag-name.  NBB this is the physical, NOT
hierarchical, \"next element\"."
  (save-excursion
    (if (looking-at "<")
        (forward-char-nomark 1))
    (re-search-forward "<\\([A-Za-z0-9]*[^/> ]\\)" nil t)
    (setq next-element (match-string 1))))

(defun cursus-pos-inside-item ()
  "Cursus project editing function.

Several Cursus editing functions within a repository require point to
be somewhere after the opening tag of the item \(respond, antiphon,
prayer, app, rdg... \), or at least after the '<' of the opening tag
of an element.  This function positions point on the first letter of
the element name, unless one is dealing with an 'item' (responsory,
antiphon, prayer) in the repository file.  In this case it positions
point down one element."
  ;; position us on the current tag-name:
  (cond
    ((looking-at "<")
     (forward-char-nomark 1))
    ((not (looking-at "<"))
     (search-backward "<")
     (forward-char-nomark 1)))
  ;; check if it's an 'item', and if so move down one element:
  (cond
   ((looking-at "\\(ant\\|res\\|prayer\\)")
    (sgml-down-element)
    (cursus-pos-inside-item))
   ((looking-at "/")
    (backward-char-nomark 2)
    (cursus-pos-inside-item))))

;;}}} ---------------------------------------------------------------------------

;;{{{ Collecting data from ms file & inserting it into repository:
  
(defun cursus-set-usage-data ()
  "Cursus project editing function.

Collects details of current day-code and current manuscript siglum
from a Ms file that is the current buffer, and prepares these for
inclusion in the repository file.  Also stores ms-file name in
variable to enable return to the file."
  (interactive)
  ;; set the variable 'current-day-code':
  (save-excursion
    (re-search-backward "code=\"\\([0-9]+\\)\"" nil t)
    (setq current-day-code (match-string 1)))
  ;; set the variable 'current-ms-sigl':
  (setq current-ms-sigl
        (cadr (assoc (buffer-name) sigla)))
  (setq current-ms-file (buffer-name)))

(defun cursus-add-ms-to-main-wits ()
  (interactive)
  (save-excursion
    (get-main-wits)
    ;; test to see if the new wit is already there:
    (cond
     ((member current-ms-sigl main-wits)
      (error "ERROR! %s already among witnesses!" current-ms-sigl))
     ((not (member current-ms-sigl main-wits))
      (setq new-vals
            (mapconcat 'symbol-name 
                       (reverse (mapcar 'intern 
                                        (cons current-ms-sigl (reverse main-wits)))) " "))
      (re-search-backward "wit=\"\\(.*?\\)\"" nil t)
      (replace-match new-vals t t nil 1)))))

(defun cursus-add-usage-info ()
  "Cursus editing function.

Used while editing a repository item, this function makes a <usage>
tag which records the occurrence of the current item in the Ms being
edited."
  (interactive)
  (save-excursion
    (re-search-backward "<ant\\|<res\\|<prayer" nil t)
    (cursus-record-next-physical-element)
    ;; There's a <header> already:
    (if
     (equal next-element "header")
     (progn
       (search-forward "<header>" nil t)
       (insert "\n")
       (sgml-indent-or-tab)
       (insert "<usage ms=\""current-ms-sigl"\" code=\""current-day-code"\"></usage>"))
     ;; There's as yet no <header> element:
     (progn
       (re-search-forward "id=\"\\([a-z][0-9]+\\)\">" nil t)
       (insert "<header>\n")
       (sgml-indent-or-tab)
       (insert "<usage ms=\""current-ms-sigl"\" code=\""current-day-code"\"></usage>\n</header>")))))

(defun cursus-insert-usage-data ()
  "Cursus project editing function.

Used after going to a repository item from a manuscript file, this
will insert upon request the proper siglum of the Ms file among the
'wit' values, and (also upon request) the <usage> tag, with all
attribs and values, for the Ms you are editing."
  (interactive)
  (if
   (y-or-n-p "Add manuscript siglum?")
   (cursus-add-ms-to-main-wits))
  (if
   (y-or-n-p "Add usage data?")
   (cursus-add-usage-info)))
(define-key xml-mode-map "\C-ccu" 'cursus-insert-usage-data)

;;}}} ---------------------------------------------------------------------------

;;{{{ Editing repository and inserting repository data into Ms files:

;; -- creating an <app>:

(defun find-main-wits ()
  "Function for use in editing CURSUS repository files.

Finds the value of the 'wit' attribute in the enclosing main body tag
\(e.g. 'rBody', 'aBody' etc\) and saves it as the variable 'main-wits'."
  (interactive)
  (save-restriction
    (save-excursion
      (re-search-backward "<rBody\\|<aBody\\|<vBody\\|<pBody")
      (search-forward " wit=\"")
      (setq wit-start (point))
      (re-search-forward "\"")
      (backward-char-nomark 1)
      (setq wit-end (point))
      (narrow-to-region wit-start wit-end)
      (setq main-wits (buffer-string))
      (widen))))

(defun cursus-get-outside-tag ()
  (interactive)
  (save-excursion
    (re-search-backward "\\(<\\|>\\)" nil t))
    (cond
      ((equal (match-string 0) "<")
       (search-forward ">" nil t))
      (t
       nil)))

(defun cursus-add-ms-to-current-wits ()
  (interactive)
  (save-excursion
    (cursus-get-outside-tag)
    ;; action depends on testing existence of @wit:
    (cond
      ((wit-exists-p)
       (get-current-wits)
       ;; test to see if the new wit is already there:
       (cond
         ((member current-ms-sigl curr-wits)
          (error "ERROR! %s already among witnesses!" current-ms-sigl))
         ((not (member current-ms-sigl curr-wits))
          (setq new-vals
                (mapconcat 'symbol-name 
                           (reverse (mapcar 'intern 
                                            (cons current-ms-sigl (reverse curr-wits)))) " "))
          (re-search-backward "wit=\"\\(.*?\\)\"" nil t)
          (replace-match new-vals t t nil 1))))
      (t 
       (sgml-insert-attribute "wit" current-ms-sigl)))))

(defun wit-exists-p ()
  (interactive)
  (save-excursion
    (re-search-backward "<aBody\\|<rBody\\|<vBody\\|<pBody\\|<rdg\\|<rep\\|<dox\\|<prosula")
    (setq tag-start (point))
    (search-forward ">")
    (setq tag-end (point))
    (goto-char tag-start)
    (search-forward "wit=\"" tag-end t)))

(defun cursus-edit-repos (words)
  "Function for use in editing CURSUS repository files.

This function simply combines a number of routines which are used
repetitively in editing apparatus in the repository.  With point at
the beginning of a potential lemma, it asks for the number of words in
the lemma and creates an <app> with initial <rdg>.  The content of the
lemma is placed at the top of the kill-ring for optional insertion in
the <rdg> and subsequent emendation.

psgml may well ask, during this routine, for information about
e.g. the wit attribute to be included.  This should be overridden with
\[ENTER\] -- there are Cursus routines to insert the correct values
for the 'wit' attribute after the content of the <rdg> has been
entered."
  (interactive "nNumber of words in lemma: ")
  (find-main-wits)
  (push-mark)
  (save-restriction
    (save-excursion
      (insert "\n")
      (forward-word-mark words)
      (copy-region-as-kill (mark) (point))
      (sgml-tag-region "app" (mark) (point))
      (sgml-beginning-of-element)
      (forward-char-nomark 1)
      (push-mark)
      (forward-word-mark words)
      (sgml-tag-region "rdg" (mark) (point)))
    (sgml-next-data-field)
    (sgml-insert-attribute "wit" main-wits)
    (sgml-up-element)
    (sgml-insert-element "rdg")
    (save-excursion
      (push-mark)
      (sgml-next-data-field)
      (sgml-indent-or-tab)
      (mark)))
;;   (insert " ")
  )

;; -- dealing with @wit vals inside an <app>

(defun get-first-app-wits ()
  (save-excursion
    (search-backward "<app" nil t)
    (re-search-forward "wit=\"\\(.*?\\)\"" nil t)
    (setq 1-app-wits (split-string (regexp-quote (match-string 1))))))

(defun get-current-wits ()
  (save-excursion
    (search-backward "wit" nil t)
    (re-search-forward "=\"\\(.*?\\)\"" nil t)
    (setq curr-wits (split-string (regexp-quote (match-string 1))))))

(defun get-main-wits ()
  (save-excursion
    (re-search-backward "\\(<aBody\\|<rBody\\|<pBody\\)" nil t)
    (re-search-forward "wit=\"\\(.*?\\)\"" nil t)
    (setq main-wits (split-string (regexp-quote (match-string 1))))))

(defun rewrite-first-app-wits ()
  (save-excursion
    ;; check first that every witness is among those in the first <rdg> wits:
    (cond
      ((not (subsetp (mapcar 'intern curr-wits) (mapcar 'intern 1-app-wits)))
       (setq error-wit (set-difference curr-wits 1-app-wits :test #'string=))
       (error "ERROR: %s missing from the first <rdg>" error-wit))
      ;; all well, so create the new wits for the first <rdg> and
      ;; replace the old set:
      ((setq new-vals
             (mapconcat 'symbol-name 
                        (reverse 
                         (mapcar 'intern (set-difference 1-app-wits curr-wits :test #'string=))) " "))
       (search-backward "<app" nil t)
       (re-search-forward "wit=\"\\(.*?\\)\"" nil t)
       (replace-match new-vals nil t nil 1)))))

(defun cursus-clean-app-wits ()
    "Cursus project editing function (repository).

Erases the values of the @wit in the current <rdg> tag from the values
of the @wit in the first <rdg> tag of an <app>.  Shows error if no wit
value for current element."
  (interactive)
  (get-first-app-wits)
  (get-current-wits)
  ;; check there's a value to the @wit on the current line:
  (cond
    (curr-wits
     (rewrite-first-app-wits))
    (t
     (error "ERROR: no current wit value"))))

(defun cursus-get-my-id-number ()
  "Cursus project editing function.

Stores in a variable the id number of the current repository item."
  (save-excursion
    (re-search-backward "\\(\\(ant \\|res \\|prayer \\)id=\"\\)\\([a-z][0-9]+\\)")
    (setq my-id-number (match-string 3))))

(defun cursus-get-current-id-refs ()
  (save-excursion
    (re-search-backward "\\(id=\"\\)\\([a-z]\\([0-9]+[a-z]?\\)\\)")
    (setq current-full-id (match-string 2))
    (setq current-id-number-only (match-string 3))))

(defun cursus-insert-id-number ()
  "Cursus project editing function.  

When you have just added manuscript information to an item in the
repository and need to insert its id-number into the correct place in
a pre-prepared template of respond, antiphon or prayer, this will take
you back to the manuscript file make the insertion.  If the item is a
respond it will deal with the verse too."
  (interactive)
  (cursus-get-current-id-refs)
  (cond
    ((eq cursus-write-logfile t)
     (cursus-create-or-update-repos-logfile)))
  (switch-to-buffer current-ms-file)
  (cond
    ((equal item-type 'respond)
     (search-forward "ID(c" nil t)
     (insert current-id-number-only)
     (search-forward "ID(c" nil t)
     (insert current-id-number-only)
     (search-forward "</respond>" nil t))
    ((equal item-type 'antiphon)
     (search-forward "ID(c" nil t)
     (insert current-id-number-only)
     (search-forward "</antiphon>" nil t))
    ((equal item-type 'invitatory)
     (search-forward "ID(c" nil t)
     (insert current-id-number-only)
     (search-forward "</invitatory>" nil t))
    ((equal item-type 'prayer)
     (search-forward "ID(o" nil t)
     (insert current-id-number-only)
     (search-forward "</prayer>" nil t))))

(defun cursus-create-or-update-repos-logfile ()
  "Cursus editing function.

Creates (where necessary) and updates a log-file whose path and name
is specified in the variable `repos-log-file'.  This file records
edits to items in *repository.xml*.  The logfile will be sorted by
order of repository @id numbers if the variable `cursus-sort-log' is
set to t.  If the value of that variable is nil, this function will
simply add successive edits at the end of the log.

This function can be shut off by setting the variable
`cursus-write-logfile' to nil.  No log file will then be written."
  (interactive)
  (if
   (file-exists-p repos-log-file)
   (progn
     (set-buffer (find-file-noselect repos-log-file))
     (goto-char (point-min))
     (search-forward "Ms:")
     (forward-char-nomark 1)
     (setq beg (point))
     (goto-char (point-max)))
   (progn
     (set-buffer (find-file-noselect repos-log-file))
     (insert "This file created: ")
     (insert-date)
     (insert "\n"(make-string 43 ?-)"\n\nItem number:"(make-string 4 ? )"Edited on:"(make-string 18 ? )"Ms:\n\n")
     (setq beg (point))))
   (insert current-full-id (make-string 11 ? ))
   (insert-date) 
   (insert (make-string 4 ? ))
   (insert current-ms-sigl"\n")
   (cond
     ((eq cursus-sort-log t)
      (sort-lines nil beg (point))))
   (basic-save-buffer))

(defun cursus-make-new-milestone ()
  "Cursus project editing function.  

Adds new <milestone> tag automagically."
  (interactive)
  (save-excursion
    (save-restriction
      (search-backward "<milestone n=\"" nil t)
      (re-search-forward "\\([0-9]+\\)\\([r\\|v]?\\)")
      (setq old-folio-number (string-to-number (match-string 1)))))
      (cond
        ((equal (match-string 2) "r")
         (insert "<milestone n=\""(concat (match-string 1) "v")"\" unit=\"page\"/>"))
        ((equal (match-string 2) "v")
         (insert "<milestone n=\""(concat (number-to-string (+ old-folio-number 1)) "r")"\" unit=\"page\"/>"))
        ((equal (match-string 2) "")
         (insert "<milestone n=\""(number-to-string (+ old-folio-number 1))"\" unit=\"page\"/>"))))

;;}}} ---------------------------------------------------------------------------

;;{{{ Cross-referencing in manuscript files

(defun cursus-get-ms-sigl ()
  "Cursus project editing function.

Sets correct siglum for Ms of current manuscript file."
  (setq ms-sigl (cadr (assoc (buffer-name) sigla))))

(defun cursus-uniquify-refs ()
  "Cursus project editing function.

Creates a fresh number for use in the cross-referencing of elements in
a file."
  (interactive)
  (setq new-num "1001")
  (save-excursion
    (goto-char (point-min))
    (while
        (re-search-forward "\\(id\\|corresp\\)=\"[- A-Za-z0-9]+_\\([0-9]+\\)\"" nil t)
      (progn
        (setq old-num (match-string 2))
        (if
         (>= (string-to-number old-num) (string-to-number new-num))
         (setq new-num (add-one-to-stringnum old-num)))))))

(defun cursus-get-attr-vals (attr)
  "Gets the values of the attribute ATTR as a list.  NBB if the ATTR
is 'id', the list will be of one element.  If ATTR is 'corresp' it may
be one or more elements."
  (interactive)
  (setq attr-vals nil)
  (save-excursion
    (search-backward "<" nil t)
    (cond 
      ((looking-at "</")
       (forward-char -2)
       (search-backward "<"))
      (t nil))
    (setq tag-beg (point))
    (search-forward ">" nil t)
    (setq tag-end (point))
    (goto-char tag-beg)
    (cond
     ((search-forward (concat attr "=\"") tag-end t)
      (setq beg (point))
      (search-forward "\"" nil t)
      (backward-char 1)
      (setq end (point))
      (setq attr-vals (split-string (regexp-quote (buffer-substring beg end))))))))

(defun cursus-add-to-attr-vals (attr val)
  "Adds VAL to the existing values of ATTR."
  (cursus-pos-inside-item)
  ;; TODO - why didn't I use a list here??!
  (search-forward (concat attr "=\"") nil t)
  (search-forward "\"" nil t)
  (backward-char-nomark 1)
  (insert " " val))

(defun cursus-crossref1 ()
  "Cursus editing function.

First part of TEI cross-referencing procedure.  "
  (interactive)
  (cursus-uniquify-refs)
  (cursus-get-ms-sigl)
  (setq attr-vals ())
  ;; is there an 'id' already?
  (if
   (cursus-get-attr-vals "id")
   ;; yes, so capture it:
   (setq val1 (pop attr-vals))
   ;; no, so insert it:
   (progn
     (setq val1 (concat ms-sigl "_" new-num))
     (sgml-insert-attribute "id" val1)))
  (bookmark-set "xref-place")
  (message "Now go to the element to be cross-referenced and do Ctrl-c c Ctrl-x 2."))
(define-key xml-mode-map "\C-cc\C-x1" 'cursus-crossref1)

(defun cursus-crossref2 ()
  "Second part of TEI cross-referencing procedure."
  (interactive)
  ;; Is there an 'id' attribute already?
  (if
   (cursus-get-attr-vals "id")
   ;; Yes:
   (setq val2 (pop attr-vals))
   ;; No:
   (progn
     (setq val2 (concat ms-sigl "_" (add-one-to-stringnum new-num)))
     (sgml-insert-attribute "id" val2)))
  ;; (I think we may be skipping a usable number here.  Needs a test
  ;; to see if new-num can be re-cycled if it has not been previously
  ;; used.) -- TODO
;;   Is there a 'corresp' attribute already?
  (if
   (cursus-get-attr-vals "corresp")
   ;; yes
   (cursus-add-to-attr-vals "corresp" val1)
   ;; no:
   (sgml-insert-attribute "corresp" val1))
  ;; Ask about returning to the first element:
  (cond
   ((y-or-n-p "OK to return to first item and complete cross-reference?")
    (bookmark-jump "xref-place")
    (if
     (cursus-get-attr-vals "corresp")
     (cursus-add-to-attr-vals "corresp" val2)
     (sgml-insert-attribute "corresp" val2))
    (bookmark-delete "xref-place")
    (message "Cross-referencing completed."))))
(define-key xml-mode-map "\C-cc\C-x2" 'cursus-crossref2)

;;}}} ---------------------------------------------------------------------------

;;{{{ Cross-referencing in the repository file:

(defun cursus-insert-vbody-crossref ()
  "Cursus project editing function.  

Inserts 'id' and 'crossref' attribs in a <vBody> and the (physically)
following <rep>, with correct values.  Useful when a manuscript has
multiple versions of a respond, with different regressiones."
  (interactive)
  (save-excursion
    (save-restriction
      (cursus-get-my-id-number)
      (search-backward "<res")
      (setq res-start (point))
      (search-forward "</res>")
      (setq res-end (point))
      (goto-char res-end)
      ;; initialise the id value (it will default to this):
      (setq old-value "1")
      ;; look for an existent id attribute and, if it exists, find its value:
      (while
          (re-search-backward "<vBody id=\"\\([a-z][0-9]+[a-z]?-\\)\\([0-9]+\\)" res-start t)
        ;; if id value found, test it and adjust if necessary:
        (progn
          (setq new-value (match-string 2))
          (if
           (>= (string-to-number new-value) (string-to-number old-value))
           (setq old-value (number-to-string (+ (string-to-number new-value) 1))))))
      ;; 'old-value' is now correct, whether or not we have found an existing one.
      ;; Now construct the full value for the id attribute:
      (setq new-id-value (concat my-id-number "-" old-value))
      (widen)))
      ;; insert the attribute + value:
      (sgml-insert-attribute "id" new-id-value)
      ;; now add the 'corresp' attribute + value ??
      (if (y-or-n-p "Insert corresp attribute in the immediately following <rep>? ")
          (progn
            (search-forward "<rep" nil t)
            (sgml-insert-attribute "corresp" new-id-value))
          (message "Then you'll have to do it by hand later...")))

;;}}} ---------------------------------------------------------------------------

;;{{{ Creating <index> tags in manuscript files:

(defun cursus-make-index (beg end)
  "Cursus project editing function.

If a word or phrase is made into the region, this function steps you
through the creation of a TEI <index> tag for any or all of the words
in that region, and makes the attributes + values for the tag."
  (interactive "r")
  ;; get the region as a list of words:
  (setq words (split-string (buffer-substring beg end)))
  (if (> (point) (mark))
      (exchange-point-and-mark))
    ;; if there's only one word in region:
  (cond
    ((equal (length words) 1)
     (setq one (read-string "Form of word: " (car words)))
     (goto-char (point))
     (insert "<index level1=\""one"\"/>"))
  ;; if there's more than one word in region:
    ((> (length words) 1)
     ;; ask for number of levels (but show error if more than 4):
     (if
      (> (string-to-number (setq levels (read-string "How many levels of index? \(2-4\): "))) 4)
      (error "Only four levels allowed!"))
     ;; get top-level word:
     (setq first (read-string "Which word at top level? \(1 2 ...\): "))
     (setq lvl1 (read-string "Edit word-form if necessary:  " (index-words first)))
     ;; Make sure we stop when we've got to the last level required
     ;; (we've used one of the four already):
     (setq levels (number-to-string (- (string-to-number levels) 1)))
     (setq entries ())
     (while
         (> (string-to-number levels) 0)
       ;; var 'next' will be the level.  Get its position in the string:
       (setq next (read-string "Which word at the next level? \(1 2 ...\): "))
       ;; convert it to its actual word:
       (setq next (read-string "Edit word-form if necessary:  " (index-words next)))
       ;; push it on to 'entries':
       (push next entries)
;;        (setq next nil)  ;; (can't see why this was necessary)
       ;; reset the 'levels' var for the next time round:
       (setq levels (number-to-string (- (string-to-number levels) 1))))
     ;; The entries are all done, so get the list into the right order
     ;; for 'pop':
     (setq entries (reverse entries))
     (goto-char (point))
     ;; make a list for the tag-attributes:
     (setq attr-levels '("level2" "level3" "level4"))
     ;; do the first one by steam-power:
     (insert "<index level1=\""lvl1"\"")
     ;; do the rest of them by popping off the lists:
     (while
         entries
       (insert " "(pop attr-levels)"=\""(pop entries)"\""))
     (insert "/>"))))

(define-key xml-mode-map "\C-cc\C-xi" 'cursus-make-index)

(defun index-words (x)
  "Slave function for cursus-make-index."
  (cond
    ((equal x "0")
     (setq word ()))
    ((equal x "1")
     (setq word (car words)))
    ((equal x "2")
     (setq word (cadr words)))
    ((equal x "3")
     (setq word (caddr words)))
    ((equal x "4")
     (setq word (cadddr words)))
    ((equal x "5")
     (setq word (fifth words)))))

;;}}} ---------------------------------------------------------------------------

;;{{{ Getting and displaying information:

(defun cursus-find-place ()
  "Cursus project editing function.  Identifies current Ms folio.

Looks for the 'n' value in the last <milestone> tag and uses the
minibuffer to tell you where you have got to in your source.
Typically used for orientation when working in a manuscript file."
  (interactive)
  (save-excursion
    (save-restriction
      (search-backward "<milestone" nil t)
      (re-search-forward "n=\"\\([0-9]+[r\\|v]?\\)\"")
      (message "This is fol/pg %s." (match-string 1)))))

(defun cursus-find-day ()
  "Cursus project editing function.  Identifies current liturgical 'day'.

Reports in the minibuffer the values that relate to the current <Day>
or <Week> tag.  Typically used for orientation when working in a
manuscript file."
  (interactive)
  (save-excursion
    (save-restriction
      (re-search-backward "<\\(Day\\|Week\\)" nil t)
      (re-search-forward "code=\"\\([0-9]+\\)\"" nil t)
      (setq code (match-string 1))
      (let
          ((lat (cadr (assoc code occasions)))
           (eng (caddr (assoc code occasions)))
           (date (cadddr (assoc code occasions))))
        (cond
          ((string-equal (cadddr (assoc code occasions)) "")
           (message "This is currently %s - %s (code %s)" lat eng code))
          (t
           (message "This is currently %s - %s: %s (code %s)" lat eng date code)))))))

(defun cursus-capture-daycode ()
  (save-excursion
    (search-forward "</usage>" nil t)
    (setq end (point))
    (search-backward "<usage" nil t)
    (re-search-forward "code=\"\\([0-9]+\\)\"" end t)
    (setq code (match-string 1))))

(defun cursus-translate-daycode ()
  "Cursus project editing function.  Gives information about a daycode.

Reads a day code from a <usage> tag on the current line and returns
the corresponding information in the minibuffer.  Typically used for
obtaining information when in the repository file."
  (interactive)
  (cursus-capture-daycode)
  (let
      ((lat (cadr (assoc code occasions)))
       (eng (caddr (assoc code occasions)))
       (date (cadddr (assoc code occasions))))
    (cond
      ((string-equal (cadddr (assoc code occasions)) "")
       (message "Code %s: %s - %s" code lat eng))
      (t
       (message "Code %s: %s - %s (%s)" code lat eng date)))))

(defun cursus-find-daycode ()
  "Cursus project function.  Finds a daycode.

Display in temporary buffer the lines of the file occasions.txt which
have a match for a string entered in the minibuffer.  Typically this
will be used when needing to find a code for a new <Day> or <Week> tag
in a manuscript file, which can be copied from the temporary buffer to
the kill-ring for subsequent use."
  (interactive)
  (setq str (read-string "Search for: "))
  (find-file-noselect occ-file)
  (set-buffer "occasions.txt")
  (goto-char (point-min))
  (with-output-to-temp-buffer "Occasions"
    (while
        (search-forward str nil t)
        (forward-line 0)
        (re-search-forward ".*" nil t)
        (setq ln (match-string 0))
        (princ (format "%s\n" ln))
        (end-of-line))))

(defun cursus-find-repos-item ()
  "Cursus project editing function.

When in a manuscript file, with point inside an <xptr/> tag that
points to an item in the file repository.xml, this function will
display in another buffer that item from the repository file \(which
must be already present in some buffer or other\).  "
  (interactive)
  (save-excursion
    (search-forward "/>" nil t)
    (setq end (point))
    (search-backward "<xptr" nil t)
    (re-search-forward "\"ID(\\([co][0-9]+\\)" end t)
    (setq idnum (match-string 1)))
  (set-buffer "repository.xml")
  (goto-char (point-min))
  (re-search-forward (concat "id=\"" idnum) nil t)
  (display-buffer "repository.xml"))

;;}}} ---------------------------------------------------------------------------

;;{{{ Updating information in the file:

(defun my-capital-markup ()
  "Cursus project editing function.

Inserts TEI marking for capital letter to word.  Also uppercases the
first letter if it isn't so already.  You must be in the word
somewhere, or in the space immediately after it."
  (interactive)
  (skip-chars-forward "a-zA-Z")
  (backward-word-nomark 1)
  (insert "<hi rend=\"cap\">")
  (capitalize-word 1)
  (backward-word-nomark 1)
  (forward-char-nomark 1)
  (insert "</hi>")
  (skip-chars-forward ">a-zA-Z"))

(defun cursus-update-versionDate () 
  "Cursus project editing function.  Timestamp update.

Updates 'versionDate' timestamp in TEI header."
  (interactive)
  (save-excursion
    (save-restriction
  (goto-char (point-min))
  (if
   (search-forward "versionDate" nil t)
   (progn
     (re-search-forward "value=\"\\([-0-9]+\\)\">\\(.*\\)</date>")
     (replace-match (format-time-string "%Y-%m-%d") t nil nil 1)
     (replace-match (format-time-string "%A %d %B %Y") t nil nil 2)
     (message "Timestamp updated"))
   (error "ERROR: no timestamp found!")))))

(defun cursus-update-creationDate () 
  "Cursus project editing function.  Timestamp update.

Updates 'creationDate' timestamp in TEI header."
  (interactive)
  (save-excursion
    (save-restriction
  (goto-char (point-min))
  (if
   (search-forward "creationDate" nil t)
   (progn
     (re-search-forward "value=\"\\([-0-9]+\\)\">\\(.*\\)</date>")
     (replace-match (format-time-string "%Y-%m-%d") t nil nil 1)
     (replace-match (format-time-string "%A %d %B %Y") t nil nil 2)
     (message "Timestamp updated"))
   (error "ERROR: no timestamp found!")))))

;;}}}---------------------------------------------------------------------------

;;{{{ Getting and setting information for ms-file editing:

(defun cursus-make-lection-numbers ()
  "Cursus project editing function.

Automagically sets new numbers for lections, both the value of the
*num* attribute in the <lection> tag, and also the Roman number for
the <rubric> element.  Numbers are stored in variables for use in
templates or other functions."
  (interactive)
  (save-excursion
    (save-restriction
      (setq end (point))
      (re-search-backward "<service name=\"\\(.*\\)\"" nil t)
      (setq beg (point))
      (if 
       (search-forward "<lection num=\"1\"" end t)
       (progn
         (goto-char end)
         (save-excursion
           (re-search-backward "<lection num=\"\\([0-9]+\\)\"" nil t)
           (setq last-lect-num (match-string 1))
           (setq new-lect-num (number-to-string (+ (string-to-number last-lect-num) 1)))))
       (progn
         (goto-char end)
         (setq new-lect-num "1")))))
  (setq lect-rubric-numeral (cadr (assoc new-lect-num lection-nums)))
  (setq lect-rubric-ordinal (caddr (assoc new-lect-num lection-nums))))

(defun cursus-set-bible-book ()
  "Cursus project editing function."
  (setq src-value (read-string "Name of bible-book: "))
  ;; books whose titles begin with numeral need 'correction' in the
  ;; @href:
  (if
   ;; how do you do this more economically?
   (or
    (equal (substring src-value 0 1) "1")
    (equal (substring src-value 0 1) "2")
    (equal (substring src-value 0 1) "3")
    (equal (substring src-value 0 1) "4"))
   (setq href-value (concat (substring src-value 1) (substring src-value 0 1)))
   (setq href-value src-value))
  ;; deal with the Psalms (not sure why we did it this way):
  (if
   (equal src-value "PsalmsG")
   (setq href-value (capitalize src-value)))
  (if
   (equal src-value "PsalmsH")
   (setq href-value (capitalize src-value))))

(defun my-chapter-prefatory-text ()
  "Function for use with CURSUS chapter markup template."
  (setq my-chap-pref (read-from-minibuffer "Prefatory text: " "Haec dicit dominus. " nil nil 'template-history))
  (insert my-chap-pref" "))

(defun my-chapter-closing-text ()
  "Function for use with CURSUS chapter markup template."
  (setq my-chap-close (read-from-minibuffer "Closing text: " " ait dominus omnipotens." nil nil 'template-history))
  (insert my-chap-close))

(defun my-lection-pattern-1 ()
  "For inserting text PATTERN into CURSUS lection xml markup"
  (setq my-lection-pattern (read-string "text PATTERN: " ""))
  (insert ") PATTERN("my-lection-pattern")"))

(defun my-ferial-lection-pattern-1 ()
  "For inserting text PATTERN into CURSUS lection xml markup"
  (setq my-lection-pattern (read-string "text PATTERN: " ""))
  (insert " PATTERN("my-lection-pattern")"))

(defun my-lection-pattern-2 ()
  "For inserting text PATTERN into CURSUS lection xml markup"
  (setq my-lection-pattern (read-string "text PATTERN: " ""))
  (insert ") PATTERN("my-lection-pattern")\"/>"))

(defun my-ferial-lection-pattern-2 ()
  "For inserting text PATTERN into CURSUS lection xml markup"
  (setq my-lection-pattern (read-string "text PATTERN: " ""))
  (insert ") PATTERN("my-lection-pattern")"))

(defun my-lection-to-pointer ()
  "For inserting text PATTERN into CURSUS lection xml markup"
  (setq my-to-pointer (read-string "Closing ID: "))
  (insert "\" to=\"ID("my-to-pointer)
  (if (y-or-n-p "Insert PATTERN? ")
      (my-lection-pattern-2)
    (insert ")\"/>")))

(defun my-ferial-lection-to-pointer ()
  "For inserting text PATTERN into CURSUS lection xml markup"
  (setq my-to-pointer (read-string "Closing ID: "))
  (insert "\" to=\"ID("my-to-pointer)
  (if (y-or-n-p "Insert PATTERN? ")
      (my-ferial-lection-pattern-2)
    (insert")")))

(defun my-gospel-antiphon-rubric ()
  "Function for use with CURSUS template."
  (interactive)
  (insert " <rubric type=\"general\">")
  (if (y-or-n-p "Benedictus? ")
      (insert " Ad Benedictus.")
    (if (y-or-n-p "Magnificat?")
	(insert " Ad Magnificat. ")))
  (insert " &AE; </rubric>"))

(defun cursus-update-day-code ()
  "Cursus editing function.

Adjusts values in last <Day> tag to account for a new feria.  Shows
error if we are already in a Saturday \(it is not realistic to guess
accurately the following day\)."
  (save-excursion
    (re-search-backward "<Day" nil t)
    (re-search-forward "num=\"\\([1-7]\\)\"" nil t)
    (if (equal (match-string 1) "7")
        (error "You are at the end of a week!"))
    (setq new-num (number-to-string (+ (string-to-number (match-string 1)) 1)))
    (re-search-forward "code=\"\\([0-9]+\\)\"")
    (setq old-day-code (match-string 1))
    (setq old-week-code (substring old-day-code 0 4))
    (setq old-feria-code (substring old-day-code 4 8))
    (setq new-day-code (concat old-week-code (number-to-string (+ (string-to-number old-feria-code) 1000))))
    (setq new-desc (third (assoc (string-to-number new-num) ferias)))))

(defun cursus-make-new-feria-tag ()
  "Cursus project editing function.

Makes full template for a <Day> element for a new feria, with all
attribute-values automagically calculated.  Will also, upon request,
insert tags and content for the <rubric> element.  Returns an error if
the last day was a Saturday -- you will need to insert a new Sunday
'by hand'."
  (interactive)
  (cursus-update-day-code)
  (setq feria-ordinal (second (assoc (string-to-int new-num) ferias)))
  (if
   (y-or-n-p "Insert outline marker?")
   (insert "<!--\n**  "new-desc"\n -->\n"))
  (setq beg (point))
  (insert "<Day num=\""new-num"\" code=\""new-day-code"\">")
  (sgml-indent-or-tab)
  (insert "\n")
  (sgml-indent-or-tab)
  (if
   (confirm "Insert day-rubric?")
   (progn
     (cond
       ((< (string-to-int new-num) 7)
        (insert "<rubric type=\"dayTitle\">Feria "feria-ordinal".</rubric>"))
       ((equal new-num "7")
        (insert "<rubric type=\"dayTitle\">Sabbato.</rubric>")))
     (sgml-indent-or-tab)
     (insert "\n")))
  (sgml-indent-or-tab)
  (setq insert (point))
  (insert "\n</Day>")
  (sgml-indent-or-tab)
  (goto-char insert))


;;}}}----------------------------------------------------------------------

;;{{{ Outline markers for manuscript files:

(tempo-define-template "cursus-level-one"
		       '("<!-- "
			 n
			 "* "
			 (P "Level 1 text: ")
			 n
			 " -->"
			 ))
(define-abbrev xml-mode-abbrev-table "'lvl1" "" 'tempo-template-cursus-level-one)

(defun my-cursus-day ()
  "Function to put text for 'Day' into level 2 Cursus outline marker"
  (interactive)
  (setq my-cursus-day (read-from-minibuffer "Day: " "Sunday" nil nil 'cursus-day-history))
  (insert my-cursus-day))

(tempo-define-template "cursus-level-two"
		       '("<!-- "
			 n
			 "**  "
			 (my-cursus-day)
			 n
			 " -->"
			 ))
(define-abbrev xml-mode-abbrev-table "'lvl2" "" 'tempo-template-cursus-level-two)

(defun my-cursus-service ()
  "Function to put text for 'Service' into level 3 Cursus outline marker"
  (interactive)
  (setq my-cursus-service (read-from-minibuffer "Service: " "First Vespers" nil nil 'cursus-service-history))
  (insert my-cursus-service))

(tempo-define-template "cursus-level-three"
		       '("<!-- "
			 n
			 "***   "
			 (my-cursus-service)
			 n
			 " -->"
			 n
			 ))
(define-abbrev xml-mode-abbrev-table "'lvl3" "" 'tempo-template-cursus-level-three)

(defun my-cursus-subservice ()
  "Function to put text for 'Sub-service' into level 4 Cursus outline marker"
  (interactive)
  (setq my-cursus-subservice (read-from-minibuffer "Sub-service: " "First Nocturn" nil nil 'cursus-subservice-history))
  (insert my-cursus-subservice))

(tempo-define-template "cursus-level-four"
		       '("<!--"
			 n
			 "****    "
			 (my-cursus-subservice)
			 n
			 " -->"
			 n
			 ))
(define-abbrev xml-mode-abbrev-table "'lvl4" "" 'tempo-template-cursus-level-four)

;;}}} ---------------------------------------------------------------------------

;;{{{ Functions for inserting entities in manuscript files:

(defun cursus-punctel-entity ()
  "Insert entity for punctus elevatus in Cursus xml files"
  (interactive)
  (insert "&punct-el; "))

(defun cursus-colon-entity ()
  "Insert entity for colon in Cursus xml files"
  (interactive)
  (insert "&colon; "))

(defun cursus-virgule-entity ()
  "Insert entity for virgule in Cursus xml files"
  (interactive)
  (insert "&virgule; "))

(defun cursus-punctus-entity ()
  "Insert entity for punctus in Cursus xml files"
  (interactive)
  (insert "&punctus; "))

(defun cursus-etrel-entity ()
  "Insert entity for 'Et reliqua' in Cursus xml files"
  (interactive)
  (insert "&Etrel; "))

(defun cursus-etc-entity ()
  "Insert entity for 'Et cetera' in Cursus xml files"
  (interactive)
  (insert "&etc; "))

(defun cursus-hook-entity ()
  "Insert entity for 'hook contraction' in Cursus xml files"
  (interactive)
  (insert "&hook; "))

(defun cursus-verse-entity ()
  "Insert entity for V' in Cursus xml files"
  (interactive)
  (insert "&V; "))

(defun cursus-evovae-entity ()
  "Insert entity for 'evovae' (&Ev;) in Cursus xml files"
  (interactive)
  (insert "&Ev; "))

(defun cursus-bar-entity ()
  "Insert entity for superior bar contraction-mark (&bar;)"
  (interactive)
  (insert "&bar;"))

(defun cursus-para-entity ()
  "Insert entity for paragraph mark (&para;)"
  (interactive)
  (insert "&para; "))

;;}}} ---------------------------------------------------------------------------

;;{{{ Functions & templates for inserting complete items in manuscript files:

;;{{{ --- lessons:

(defun cursus-biblical-with-xptr ()
  "Function for use with CURSUS template.

Writes the whole of a <biblical> element, including its enclosed
<xptr/> tag, whose values it takes from the minibuffer."
  (interactive)
  (setq opening-id (read-string "Opening ID: "))
  (insert "<biblical src=\""src-value"\"><xptr type=\"Bible\" href=\""href-value"\" from=\"ID("opening-id")")
  (if (y-or-n-p "Insert opening PATTERN? ")
      (my-ferial-lection-pattern-1)
    (insert""))
  (if (y-or-n-p "Insert closing ID? ")
      (my-ferial-lection-to-pointer)
    (insert""))
  (insert "\"/></biblical>"))

(defun cursus-insert-bibl-lect ()
  "Cursus project editing function.

Inserts in Ms file a template for a biblical <lection> in matins."
  (interactive)
  (cursus-make-lection-numbers)
  (cursus-set-bible-book)
  (cond
    ((<= (string-to-number new-lect-num) 12)
     (insert "<lection num=\"" new-lect-num "\" type=\"bible\">")
     (sgml-indent-or-tab)
     (cond
       ((y-or-n-p "Numeral in rubric? ")
        (insert "\n<rubric type=\"lectionTitle\">Lectio "lect-rubric-numeral" &punctus;</rubric>"))
       ((y-or-n-p "Ordinal in rubric? ")
        (insert "\n<rubric type=\"lectionTitle\">Lectio "lect-rubric-ordinal" &punctus;</rubric>")))
     (sgml-indent-or-tab))
    ((> (string-to-number new-lect-num) 12)
     (insert "<lection num=\""new-lect-num"\" type=\"gospel\">")
     (sgml-indent-or-tab)
     (insert "\n<rubric type=\"lectionTitle\">")
     (insert (read-string "Title rubric: "))
     (insert "</rubric>")
     (sgml-indent-or-tab)))
    (if (y-or-n-p "Add \"In illo tempore\"? ")
        (progn
          (insert "\nIn illo tempore&punct-el; ")
          (sgml-indent-or-tab))
        (progn
          (insert "\n")
          (sgml-indent-or-tab)))
    (cursus-biblical-with-xptr)
    (if (y-or-n-p "Add \"Et reliqua\"? ")
        (insert " &Etrel;"))
    (insert "</lection>"))
;; abbrev 'lb:
(define-abbrev xml-mode-abbrev-table "'lb" "" 'cursus-insert-bibl-lect)

(defun cursus-insert-bibl+hom-lect ()
  "Cursus project editing function.

Inserts in a Ms file a template for a lesson with biblical +
non-biblical material."
  (interactive)
  (cursus-make-lection-numbers)
  (cursus-set-bible-book)
  (insert "<lection num=\"" new-lect-num "\" type=\"homily\">\n")
  (sgml-indent-or-tab)
  (cond
    ((y-or-n-p "Numeral in rubric? ")
     (insert "<rubric type=\"lectionTitle\">Lectio "lect-rubric-numeral" &punctus;</rubric>\n"))
    ((y-or-n-p "Ordinal in rubric? ")
     (insert "<rubric type=\"lectionTitle\">Lectio "lect-rubric-ordinal" &punctus;</rubric>\n")))
  (sgml-indent-or-tab)
  (cursus-biblical-with-xptr)
  (insert "\n")
  (sgml-indent-or-tab)
  (setq hom (point))
  (insert "\n</lection>")
  (sgml-indent-or-tab)
  (goto-char hom))
;; abbrev 'lbh:
(define-abbrev xml-mode-abbrev-table "'lbh" "" 'cursus-insert-bibl+hom-lect)

(defun cursus-insert-hom-lect ()
  "Cursus project editing function.

Inserts in a Ms file a template for a \"homily\" lesson."
  (interactive)
  (cursus-make-lection-numbers)
  (sgml-indent-or-tab)
  (insert "<lection num=\"" new-lect-num "\" type=\"homily\">\n")
  (sgml-indent-or-tab)
  (cond
    ((y-or-n-p "Numeral in rubric? ")
     (insert "<rubric type=\"lectionTitle\">Lectio "lect-rubric-numeral" &punctus;</rubric>\n"))
    ((y-or-n-p "Ordinal in rubric? ")
     (insert "<rubric type=\"lectionTitle\">Lectio "lect-rubric-ordinal" &punctus;</rubric>\n")))
  (sgml-indent-or-tab)
  (setq hom (point))
  (insert "\n</lection>")
  (sgml-indent-or-tab)
  (goto-char hom))
;; abbrev 'lh:
(define-abbrev xml-mode-abbrev-table "'lh" "" 'cursus-insert-hom-lect)

(defun cursus-insert-vita-lect ()
  "Cursus project editing function.

Inserts in a Ms file a template for a \"vita\" lesson."
  (interactive)
  (cursus-make-lection-numbers)
  (sgml-indent-or-tab)
  (insert "<lection num=\"" new-lect-num "\" type=\"vita\">\n")
  (sgml-indent-or-tab)
  (cond
    ((y-or-n-p "Numeral in rubric? ")
     (insert "<rubric type=\"lectionTitle\">Lectio "lect-rubric-numeral" &punctus;</rubric>\n"))
    ((y-or-n-p "Ordinal in rubric? ")
     (insert "<rubric type=\"lectionTitle\">Lectio "lect-rubric-ordinal" &punctus;</rubric>\n")))
  (sgml-indent-or-tab)
  (setq hom (point))
  (insert "\n</lection>")
  (sgml-indent-or-tab)
  (goto-char hom))
;; abbrev 'lh:
(define-abbrev xml-mode-abbrev-table "'lv" "" 'cursus-insert-vita-lect)

(defun cursus-insert-gospel-lect ()
  "Cursus project editing function.

Inserts in a Ms file a template for the Gospel reading in the third
nocturn of Matins."
  (interactive)
  (cursus-set-bible-book)
  (insert "<lection num=\"13\" type=\"gospel\">\n")
  (sgml-indent-or-tab)
  (insert "<rubric type=\"lectionTitle\">")
  (read-string "Title in Ms: ")
  (insert "</rubric>\n")
  (sgml-indent-or-tab)
  (if (y-or-n-p "Add \"In illo tempore\"? ")
      (insert "In illo tempore&punct-el; "))
  (cursus-biblical-with-xptr)
  (insert "</lection>"))
;; abbrev 'lg:
(define-abbrev xml-mode-abbrev-table "'lg" "" 'cursus-insert-gospel-lect)

(tempo-define-template "cursus-chapter"
                       '((cursus-set-bible-book)
                         "<chapter>&C; "
			 (if (y-or-n-p "Prefatory text? ")
			     (my-chapter-prefatory-text)
			   )
                         n > >
                         (cursus-biblical-with-xptr)
			   (if (y-or-n-p "Closing text? ")
			       (my-chapter-closing-text)
			     )
                         n > >
                         "</chapter>"))
;; abbrev 'cap:
(define-abbrev xml-mode-abbrev-table "'cap" "" 'tempo-template-cursus-chapter)

;;}}} -----------------------------------

;;{{{ --- responds:

(defun cursus-suggest-respond-number ()
  "Cursus project editing function, run from template function.

In a manuscript file, will automagically calculate the correct value for
the num attribute in a <respond> tag."
  (save-excursion
    (save-restriction
      (setq end (point))
      ;; find the beginning of the service we're in:
      (re-search-backward "<service name=\"\\(.*\\)\"")
      (setq beg (point))
      (if
       (search-forward "<respond num=\"1\"" end t)
       (progn
         (goto-char end)
         (save-excursion
           (re-search-backward "<respond num=\"\\([0-9]+\\)\"" nil t)
           (setq last-resp-num (match-string 1))
           (setq new-resp-num (number-to-string (+ (string-to-number last-resp-num) 1)))))
       (progn
         (goto-char end)
         (setq new-resp-num "1")))
      )))

(defun cursus-make-resp ()
  (interactive)
  (cursus-set-usage-data)
  (setq item-type 'respond)
  (cursus-suggest-respond-number)
  (insert "<respond num=\""new-resp-num"\">")
  (sgml-indent-or-tab)
  (setq beg (point))
  (insert "\n&R; <xptr href=\"Responds\" type=\"rBody\" from=\"ID\(c\)\"/>")
  (sgml-indent-or-tab)
  (insert "\n&V; <xptr href=\"Responds\" type=\"vBody\" from=\"ID\(c\)\"/>")
  (sgml-indent-or-tab)
  (insert "\n</respond>")
  (sgml-indent-or-tab)
  (insert "\n")
  (sgml-indent-or-tab)
  (setq end (point))
  (goto-char beg))
(define-abbrev xml-mode-abbrev-table "'resp" "" 'cursus-make-resp)

(defun cursus-make-mus-resp ()
  (interactive)
  (cursus-set-usage-data)
  (setq item-type 'respond)
  (cursus-suggest-respond-number)
  (insert "<respond num=\""new-resp-num"\">")
  (sgml-indent-or-tab)
  (setq beg (point))
  (insert "\n<hi rend=\"music\">")
  (sgml-indent-or-tab)
  (insert "\n&R; <xptr href=\"Responds\" type=\"rBody\" from=\"ID\(c\)\"/>")
  (sgml-indent-or-tab)
  (insert "\n&V; <xptr href=\"Responds\" type=\"vBody\" from=\"ID\(c\)\"/>")
  (sgml-indent-or-tab)
  (insert "\n</hi>")
  (sgml-indent-or-tab)
  (insert "\n</respond>")
  (sgml-indent-or-tab)
  (insert "\n")
  (sgml-indent-or-tab)
  (setq end (point))
  (goto-char beg))
(define-abbrev xml-mode-abbrev-table "'mresp" "" 'cursus-make-mus-resp)

;;}}} -----------------------------------

;;{{{ --- antiphons of several kinds:

(defun cursus-make-antiphon ()
  (interactive)
  (cursus-set-usage-data)
  (setq item-type 'antiphon)
  (insert "<antiphon>&A; ")
  (sgml-indent-or-tab)
  (setq beg (point))
  (insert "<xptr href=\"Antiphons\" type=\"aBody\" from=\"ID\(c\)\"/></antiphon>")
  (setq end (point))
  (goto-char beg))
(define-abbrev xml-mode-abbrev-table "'ant" "" 'cursus-make-antiphon) 

(defun cursus-make-mus-antiphon ()
  (interactive)
  (cursus-set-usage-data)
  (setq item-type 'antiphon)
  (insert "<antiphon>&A; <hi rend=\"music\">")
  (sgml-indent-or-tab)
  (setq beg (point))
  (insert "<xptr href=\"Antiphons\" type=\"aBody\" from=\"ID\(c\)\"/>")
  (if
   (y-or-n-p "With evovae? ")
   (insert "&Ev; </hi></antiphon>")
   (insert "</hi></antiphon>"))
  (setq end (point))
  (goto-char beg))
(define-abbrev xml-mode-abbrev-table "'mant" "" 'cursus-make-mus-antiphon) 

(defun cursus-make-gospel-antiphon ()
  (interactive)
  (cursus-set-usage-data)
  (setq item-type 'antiphon)
  (insert "<antiphon>")
  (sgml-indent-or-tab)
  (setq beg (point))
  (if
   (y-or-n-p "Insert rubric for psalm? ")
   (my-gospel-antiphon-rubric)
   (insert "&AE; "))
  (insert "<xptr href=\"Antiphons\" type=\"aBody\" from=\"ID\(c\)\"/></antiphon>")
  (setq end (point))
  (goto-char beg))
(define-abbrev xml-mode-abbrev-table "'gant" "" 'cursus-make-gospel-antiphon) 
(define-abbrev xml-mode-abbrev-table "'eant" "" 'cursus-make-gospel-antiphon)

(defun cursus-make-mus-gospel-antiphon ()
  (interactive)
  (cursus-set-usage-data)
  (setq item-type 'antiphon)
  (insert "<antiphon>&AE; <hi rend=\"music\">")
  (sgml-indent-or-tab)
  (setq beg (point))
  (insert "<xptr href=\"Antiphons\" type=\"aBody\" from=\"ID\(c\)\"/>")
  (if
   (y-or-n-p "With evovae? ")
   (insert "&Ev; </hi></antiphon>")
   (insert "</hi></antiphon>"))
  (setq end (point))
  (goto-char beg))
(define-abbrev xml-mode-abbrev-table "'mgant" "" 'cursus-make-mus-gospel-antiphon)
(define-abbrev xml-mode-abbrev-table "'meant" "" 'cursus-make-mus-gospel-antiphon)

(defun cursus-make-canticle-antiphon ()
  (interactive)
  (cursus-set-usage-data)
  (setq item-type 'antiphon)
  (insert "<antiphon>&AC; ")
  (sgml-indent-or-tab)
  (setq beg (point))
  (insert "<xptr href=\"Antiphons\" type=\"aBody\" from=\"ID\(c\)\"/></antiphon>")
  (setq end (point))
  (goto-char beg))
(define-abbrev xml-mode-abbrev-table "'cantant" "" 'cursus-make-canticle-antiphon) 

(defun cursus-make-mus-canticle-antiphon ()
  (interactive)
  (cursus-set-usage-data)
  (setq item-type 'antiphon)
  (insert "<antiphon>&AE; <hi rend=\"music\">")
  (sgml-indent-or-tab)
  (setq beg (point))
  (insert "<xptr href=\"Antiphons\" type=\"aBody\" from=\"ID\(c\)\"/>")
  (if
   (y-or-n-p "With evovae? ")
   (insert "&Ev; </hi></antiphon>")
   (insert "</hi></antiphon>"))
  (setq end (point))
  (goto-char beg))
(define-abbrev xml-mode-abbrev-table "'mcantant" "" 'cursus-make-mus-canticle-antiphon)

(defun cursus-make-invitatory ()
  (interactive)
  (cursus-set-usage-data)
  (setq item-type 'invitatory)
  (insert "<invitatory>&I; ")
  (sgml-indent-or-tab)
  (setq beg (point))
  (insert "<xptr href=\"Antiphons\" type=\"aBody\" from=\"ID\(c\)\"/></invitatory>")
  (setq end (point))
  (goto-char beg))
(define-abbrev xml-mode-abbrev-table "'inv" "" 'cursus-make-invitatory)

(defun cursus-make-mus-invitatory ()
  (interactive)
  (cursus-set-usage-data)
  (setq item-type 'antiphon)
  (insert "<invitatory>&I; <hi rend=\"music\">")
  (sgml-indent-or-tab)
  (setq beg (point))
  (insert "<xptr href=\"Antiphons\" type=\"aBody\" from=\"ID\(c\)\"/>")
;;   (if
;;    (y-or-n-p "With evovae? ")
;;    (insert "&Ev; </hi></invitatory>")
;;    (insert "</hi></invitatory>"))
  (insert "</hi></invitatory>")
  (setq end (point))
  (goto-char beg))
(define-abbrev xml-mode-abbrev-table "'minv" "" 'cursus-make-mus-invitatory)

;;}}} -----------------------------------

;;{{{ --- hymns:

(defun cursus-increment-hymn-verse-number ()
  "Cursus editing function.

Increments verse-number of hymn."
  (save-excursion
    (re-search-backward "\\(<hVerse num=\"\\)\\([1-9]+\\)")
    (setq verse-number (number-to-string (+ (string-to-number (match-string 2))1)))))

(defun cursus-make-hymn-line ()
  (setq line (read-string "Text of verse-line: "))
  (insert "<l>"line"</l>")
  (cond
    ((y-or-n-p "Insert <gap/> element? ")
     (insert "<gap reason=\"not encoded\" resp=\""user-initials"\" extent=\"rest of verse\" /></hVerse>\n"))
    ((y-or-n-p "Another verse-line? ")
     (cursus-make-hymn-line))
    ((y-or-n-p "Close verse? ")
     (insert "</hVerse>\n")))
  (if
   (y-or-n-p "Another verse? ")
   (cursus-make-hymn-verse)
   (progn
     (insert "</hymn>\n")
     (indent-region beg (point) nil))))

(defun cursus-make-hymn-verse ()
  (cursus-increment-hymn-verse-number)
  (insert "<hVerse num=\""verse-number"\">")
  (cursus-make-hymn-line))

(defun cursus-make-hymn ()
  "Cursus editing function."
  (interactive)
  (setq beg (point))
  (insert "<hymn>&Y;\n<hVerse num=\"1\">")
  (cursus-make-hymn-line))
(define-abbrev xml-mode-abbrev-table "'ym" "" 'cursus-make-hymn)

(define-abbrev xml-mode-abbrev-table "'ym" "" 'cursus-make-hymn)

;; discarded (and rather simpler) version:

;; (defun cursus-verse-of-hymn ()
;;   "Cursus editing function.

;; Used in template to add new verses to hymn."
;;   (save-excursion
;;     (search-backward "<hymn>")
;;     (setq beg (point)))
;;   (cursus-increment-hymn-verse-number)
;;   (setq verse-line (read-string "First line of verse: "))
;;   (insert "\n <hVerse num=\""new-number"\"> "verse-line " <gap reason=\"not encoded\" resp=\"DC\" extent=\"rest of verse\" /> </hVerse>")
;;   (if (y-or-n-p "Another verse? ")
;;       (cursus-verse-of-hymn)
;;       (insert "\n </hymn>"))
;;   (indent-region beg (point) nil))

;; (tempo-define-template "hymn"
;;                        '("<hymn>&Y;" n > >
;;                          "<hVerse num=\"1\"> "
;;                          (P "First line of verse: ")
;;                          " <gap reason=\"not encoded\" resp=\"DC\" extent=\"rest of verse\" /> </hVerse>"
;;                          (if (y-or-n-p "Another verse? ")
;;                              (cursus-verse-of-hymn)
;;                              "</hymn>")))
;; (define-abbrev xml-mode-abbrev-table "'ym" "" 'tempo-template-hymn)

;;}}} -----------------------------------

;;{{{ --- versicles:

(defun cursus-make-versicle ()
  (interactive)
  (insert "<versicle>")
  (sgml-indent-or-tab)
  (insert "\n<vslVerse>&V; ")
  (sgml-indent-or-tab)
  (setq ret (point))
  (insert "</vslVerse>")
  (if
   (y-or-n-p "Include Respond element?")
   (progn
     (insert "\n<vslResp>&R; </vslResp>")
     (sgml-indent-or-tab)))
  (insert "\n</versicle>")
  (sgml-indent-or-tab)
  (goto-char ret))
(define-abbrev xml-mode-abbrev-table "'vsl" "" 'cursus-make-versicle)

;;}}} -----------------------------------

;;{{{ --- prayers:

(defun cursus-make-prayer ()
  (interactive)
  (cursus-set-usage-data)
  (setq item-type 'prayer)
  (insert "<prayer>&O; ")
  (sgml-indent-or-tab)
  (setq beg (point))
  (insert "<xptr href=\"Prayers\" type=\"prayer\" from=\"ID\(o\)\"/></prayer>")
  (setq end (point))
  (goto-char beg))
(define-abbrev xml-mode-abbrev-table "'or" "" 'cursus-make-prayer)

;;}}} -----------------------------------

;;}}} ---------------------------------------------------------------------------

;;{{{ Functions for inserting incipits:

(defun cursus-add-init-attr-2 ()
  "Cursus project editing function.

Used to add an 'init' attribute to selected <incipit> elements during
encoding of Mss."
  (interactive)
  (save-excursion
    (search-backward "<incipit" nil t)
    (search-forward ">" nil t)
    ;; get to the first non-space after an entity (NBB there may be a
    ;; space after the tag-delimiter):
    (cond
      ((looking-at " *&[A-Za-z]+;")
       (search-forward ";" nil t)
       (re-search-forward " *" nil t)))
    ;; or to the first non-space if there isn't an entity:
    (cond
      ((looking-at " ")
       (re-search-forward " *" nil t)))
    ;; get past all tags (NBB look out for spaces again):
    (while
        (looking-at " ?<")
      (search-forward ">"))
    ;; and check if it's a space:
    (if
     (looking-at " ")
     (re-search-forward "." nil t))
    ;; We should be there...  Get the next letter as a variable, making
    ;; sure it's upper-case:
    (re-search-forward "\\(.\\)" nil t)
    (setq init-val (upcase (match-string 1)))
    ;; go back & insert the attribute + value:
    (search-backward "<incipit" nil t)
    (sgml-insert-attribute "init" init-val)))

(defun cursus-antiphon-incipit ()
  (interactive)
  (insert "<incipit type=\"antiphon\">&A; ")
  (insert (read-string "Text of incipit: "))
  (insert " &punctus;</incipit>")
  (sgml-indent-or-tab)
  (cursus-add-init-attr-2))
(define-abbrev xml-mode-abbrev-table "'iant" "" 'cursus-antiphon-incipit) 

(defun cursus-mus-antiphon-incipit ()
  (interactive)
  (insert "<incipit type=\"antiphon\">&A; <hi rend=\"music\"> ")
  (insert (read-string "Text of incipit: "))
  (insert " &punctus;</hi></incipit>")
  (sgml-indent-or-tab)
  (cursus-add-init-attr-2))
(define-abbrev xml-mode-abbrev-table "'miant" "" 'cursus-mus-antiphon-incipit)
(define-abbrev xml-mode-abbrev-table "'imant" "" 'cursus-mus-antiphon-incipit)

(defun cursus-gospel-antiphon-incipit ()
  (interactive)
  (insert "<incipit type=\"antiphon\">&AE; ")
  (insert (read-string "Text of incipit: "))
  (insert " &punctus;</incipit>")
  (sgml-indent-or-tab)
  (cursus-add-init-attr-2))
(define-abbrev xml-mode-abbrev-table "'igant" "" 'cursus-gospel-antiphon-incipit)

(defun cursus-mus-gospel-antiphon-incipit ()
  (interactive)
  (insert "<incipit type=\"antiphon\">&AE; <hi rend=\"music\"> ")
  (insert (read-string "Text of incipit: "))
  (insert " &punctus;</hi></incipit>")
  (sgml-indent-or-tab)
  (cursus-add-init-attr-2))
(define-abbrev xml-mode-abbrev-table "'migant" "" 'cursus-mus-gospel-antiphon-incipit)
(define-abbrev xml-mode-abbrev-table "'imgant" "" 'cursus-mus-gospel-antiphon-incipit)

(defun cursus-invitatory-incipit ()
  (interactive)
  (insert "<incipit type=\"invitatory\">&I; ")
  (insert (read-string "Text of incipit: "))
  (insert "&punctus;</incipit>")
  (sgml-indent-or-tab)
  (cursus-add-init-attr-2))
(define-abbrev xml-mode-abbrev-table "'iinv" "" 'cursus-invitatory-incipit)

(defun cursus-mus-invitatory-incipit ()
  (interactive)
  (insert "<incipit type=\"invitatory\">&I; <hi rend=\"music\"> ")
  (insert (read-string "Text of incipit: "))
  (insert " &punctus;</hi></incipit>")
  (sgml-indent-or-tab)
  (cursus-add-init-attr-2))
(define-abbrev xml-mode-abbrev-table "'iminv" "" 'cursus-mus-invitatory-incipit)
(define-abbrev xml-mode-abbrev-table "'miinv" "" 'cursus-mus-invitatory-incipit)

(defun cursus-canticle-antiphon-incipit ()
  (interactive)
  (insert "<incipit type=\"antiphon\">&AC; ")
  (insert (read-string "Text of incipit: "))
  (insert "&punctus;</incipit>")
  (sgml-indent-or-tab)
  (cursus-add-init-attr-2))
(define-abbrev xml-mode-abbrev-table "'icantant" "" 'cursus-canticle-antiphon-incipit)

(defun cursus-mus-canticle-antiphon-incipit ()
  (interactive)
  (insert "<incipit type=\"antiphon\">&AC; <hi rend=\"music\"> ")
  (insert (read-string "Text of incipit: "))
  (insert "&punctus;</hi></incipit>")
  (sgml-indent-or-tab)
  (cursus-add-init-attr-2))
(define-abbrev xml-mode-abbrev-table "'micantant" "" 'cursus-mus-canticle-antiphon-incipit)
(define-abbrev xml-mode-abbrev-table "'imcantant" "" 'cursus-mus-canticle-antiphon-incipit)

(defun cursus-psalm-incipit ()
  (interactive)
  (insert "<incipit type=\"psalm\">&P; ")
  (insert (read-string "Text of incipit: "))
  (insert " &punctus;</incipit>")
  (sgml-indent-or-tab))
(define-abbrev xml-mode-abbrev-table "'ips" "" 'cursus-psalm-incipit)

(defun cursus-mus-psalm-incipit ()
  (interactive)
  (insert "<incipit type=\"psalm\"><hi rend=\"music\">&P; ")
  (insert (read-string "Text of incipit: "))
  (insert " &punctus;</hi></incipit>")
  (sgml-indent-or-tab))
(define-abbrev xml-mode-abbrev-table "'imps" "" 'cursus-mus-psalm-incipit)
(define-abbrev xml-mode-abbrev-table "'mips" "" 'cursus-mus-psalm-incipit)

(defun cursus-venite-incipit ()
  "Shorthand for inserting incipit for Ps.Venite"
  (insert "<incipit type=\"psalm\">&P; Venite &punctus;</incipit>")
  (sgml-indent-or-tab))
(define-abbrev xml-mode-abbrev-table "'iven" "" 'cursus-venite-incipit)

(defun cursus-magnificat-incipit ()
  "Shorthand for inserting incipit for Ps.Magnificat"
  (insert "<incipit type=\"psalm\">&P; Magnificat &punctus;</incipit>")
  (sgml-indent-or-tab))
(define-abbrev xml-mode-abbrev-table "'imag" "" 'cursus-magnificat-incipit)

(defun cursus-benedictus-incipit ()
  "Shorthand for inserting incipit for Ps.Benedictus"
  (insert "<incipit type=\"psalm\">&P; Benedictus &punctus;</incipit>")
  (sgml-indent-or-tab))
(define-abbrev xml-mode-abbrev-table "'iben" "" 'cursus-benedictus-incipit)

(defun cursus-mus-venite-incipit ()
  "Shorthand for inserting incipit with music notation for Ps.Venite"
  (insert "<incipit type=\"psalm\">&P; <hi rend=\"music\">Venite &punctus;</hi></incipit>")
  (sgml-indent-or-tab))
(define-abbrev xml-mode-abbrev-table "'miven" "" 'cursus-mus-venite-incipit-music)
(define-abbrev xml-mode-abbrev-table "'imven" "" 'cursus-mus-venite-incipit-music)

(defun cursus-mus-magnificat-incipit ()
  "Shorthand for inserting incipit with music notation for Ps.Magnificat"
  (insert "<incipit type=\"psalm\">&P; <hi rend=\"music\">Magnificat &punctus;</hi></incipit>")
  (sgml-indent-or-tab))
(define-abbrev xml-mode-abbrev-table "'mimag" "" 'cursus-mus-magnificat-incipit)
(define-abbrev xml-mode-abbrev-table "'immag" "" 'cursus-mus-magnificat-incipit)

(defun cursus-mus-benedictus-incipit ()
  "Shorthand for inserting incipit with music notation for Ps.Benedictus"
  (insert "<incipit type=\"psalm\">&P; <hi rend=\"music\">Benedictus &punctus;</hi></incipit>")
  (sgml-indent-or-tab))
(define-abbrev xml-mode-abbrev-table "'miben" "" 'cursus-mus-benedictus-incipit)
(define-abbrev xml-mode-abbrev-table "'imben" "" 'cursus-mus-benedictus-incipit)

(defun cursus-respond-incipit ()
  (interactive)
  (insert "<incipit type=\"respond\">&R; ")
  (insert (read-string "Text of incipit: "))
  (insert " &punctus;</incipit>")
  (sgml-indent-or-tab)
  (cursus-add-init-attr-2))
(define-abbrev xml-mode-abbrev-table "'iresp" "" 'cursus-respond-incipit)

(defun cursus-mus-respond-incipit ()
  (interactive)
  (insert "<incipit type=\"respond\">&R; <hi rend=\"music\"> ")
  (insert (read-string "Text of incipit: "))
  (insert " &punctus;</hi></incipit>")
  (sgml-indent-or-tab)
  (cursus-add-init-attr-2))
(define-abbrev xml-mode-abbrev-table "'miresp" "" 'cursus-mus-respond-incipit)
(define-abbrev xml-mode-abbrev-table "'imresp" "" 'cursus-mus-respond-incipit)

(defun cursus-versicle-incipit ()
  (interactive)
  (insert "<incipit type=\"versicle\">&V; ")
  (insert (read-string "Text of incipit: "))
  (insert " &punctus;</incipit>")
  (sgml-indent-or-tab))
(define-abbrev xml-mode-abbrev-table "'ivsl" "" 'cursus-versicle-incipit)

(defun cursus-prayer-incipit ()
  (interactive)
  (insert "<incipit type=\"prayer\">&O; ")
  (insert (read-string "Text of incipit: "))
  (insert " &punctus;</incipit>")
  (sgml-indent-or-tab)
  (cursus-add-init-attr-2))
(define-abbrev xml-mode-abbrev-table "'ior" "" 'cursus-prayer-incipit)

(defun cursus-chapter-incipit ()
  (interactive)
  (insert "<incipit type=\"chapter\">&C; ")
  (insert (read-string "Text of incipit: "))
  (insert " &punctus;</incipit>")
  (sgml-indent-or-tab))
(define-abbrev xml-mode-abbrev-table "'icap" "" 'cursus-chapter-incipit)

(defun cursus-preces-incipit ()
  (interactive)
  (insert "<incipit type=\"preces\">&Pr; ")
  (insert (read-string "Text of incipit: "))
  (insert " &punctus;</incipit>")
  (sgml-indent-or-tab))
(define-abbrev xml-mode-abbrev-table "'iprec" "" 'cursus-preces-incipit)
  
(defun cursus-hymn-incipit ()
  (interactive)
  (insert "<incipit type=\"hymn\">&Y; ")
  (insert (read-string "Text of incipit: "))
  (insert " &punctus;</incipit>")
  (sgml-indent-or-tab))
(define-abbrev xml-mode-abbrev-table "'iym" "" 'cursus-hymn-incipit)

(defun cursus-canticle-incipit ()
  (interactive)
  (insert "<incipit type=\"canticle\">&Cant; ")
  (insert (read-string "Text of incipit: "))
  (insert " &punctus;</incipit>")
  (sgml-indent-or-tab))
(define-abbrev xml-mode-abbrev-table "'icant" "" 'cursus-canticle-incipit)

;;}}} ---------------------------------------------------------------------------

;;{{{ Functions for making templates of Office services:

(defun cursus-make-vesp1 ()
  ""
  (interactive)
  (if
   (confirm "Add outline marker?")
   (progn
     (beginning-of-line)
     (insert "<!--\n***   First Vespers\n -->\n")))
  (insert "<service name=\"vesp1\">")
  (if (y-or-n-p "Insert rubric?")
      (insert "<rubric type=\"serviceTitle\"> Ad vesperas &punctus;</rubric>"))
  (sgml-indent-or-tab)
  (insert "\n")
  (sgml-indent-or-tab)
  (setq insert (point))
  (insert "\n</service>")
  (sgml-indent-or-tab)
  (goto-char insert))
(define-abbrev xml-mode-abbrev-table "'v1" "" 'cursus-make-vesp1)

(defun cursus-make-matins ()
  ""
  (interactive)
  (if
   (confirm "Add outline marker?")
   (progn
     (beginning-of-line)
     (insert "<!--\n***   Matins\n -->\n")))
  (insert "<service name=\"matins\">")
  (if (confirm "Insert rubric?")
      (insert "<rubric type=\"serviceTitle\">Ad matutinas &punctus;</rubric>"))
  (sgml-indent-or-tab)
  (insert "\n")
  (sgml-indent-or-tab)
  (setq insert (point))
  (insert "\n</service>")
  (sgml-indent-or-tab)
  (goto-char insert))
(define-abbrev xml-mode-abbrev-table "'mat" "" 'cursus-make-matins)

(defun cursus-make-nocturn ()
  "Cursus project editing function.

Inserts all tags for a new matins nocturn, automagically providing the
value of the 'num' attribute and suggesting a rubric in the
minibuffer.  This will only work properly if you are currently inside
a <service name=\"matins\"> element (as you ought to be)."
  (interactive)
  (save-excursion
    (save-restriction
      (setq end (point))
      ;; find the beginning of the service:
      (re-search-backward "service name=\"matins\"" nil t)
      ;; is there already a <nocturn> in the service?
      (if
       (search-forward "<nocturn num=\"1\"" end t)
       ;; if so, reset the number accordingly:
       (progn
         (goto-char end)
         (save-excursion
           (re-search-backward "<nocturn num=\"\\([0-9]\\)" nil t)
           (setq last-noct-num (match-string 1))
           (setq new-noct-num (number-to-string (+ (string-to-number last-noct-num) 1)))))
       ;; if not, set this nocturn as '1':
       (progn
         (goto-char end)
         (setq new-noct-num "1")))))
  ;; set the Latin and English ordinals of the number:
  (setq noct-verb (cadr (assoc new-noct-num nocturns))
        outl-verb (caddr (assoc new-noct-num nocturns)))
  ;; optional outline marker:
  (if 
   (y-or-n-p "Insert outline marker?")
   (progn
     (beginning-of-line)
     (insert "<!--\n****    " outl-verb " Nocturn\n -->\n")))
  ;; FIXME: psgml funcs for inserting elements seem to need attribs
  ;; to be put in during the call, so making it difficult to do this
  ;; with 'sgml-insert' funcs.  Is there a way round this ??
  ;; ...
  ;; YES -- see variable sgml-new-attribute-list-function (TODO)
  (insert "<nocturn num=\""new-noct-num"\">")
  (sgml-indent-or-tab)
  (insert "\n")
  ;; there may not be a title:
  (if
   (y-or-n-p "Insert title?")
   (progn
     (insert "<rubric type=\"nocturnTitle\"> In "noct-verb" nocturno &punctus;</rubric>")
     (sgml-indent-or-tab)
     (insert "\n")))
  (setq insert (point))
  (insert "\n</nocturn>")
  (sgml-indent-or-tab)
  (goto-char insert)
  (sgml-indent-or-tab))
(define-abbrev xml-mode-abbrev-table "'noc" "" 'cursus-make-nocturn)

(defun cursus-make-lauds ()
  ""
  (interactive)
  (if
   (confirm "Add outline marker?")
   (progn
     (beginning-of-line)
     (insert "<!--\n***   Lauds\n -->\n")))
  (insert "<service name=\"lauds\">")
  (if (y-or-n-p "Insert rubric?")
      (progn
        (cond
          ((confirm "\"In laudibus\"?")
           (setq lauds-title "In laudibus &punctus;"))
          ((confirm "\"Ad laudes\"?")
           (setq lauds-title "Ad laudes &punctus;"))
          ((setq lauds-title (read-string "Supply title: "))))
        (insert "<rubric type=\"serviceTitle\">"lauds-title"</rubric>")))
  (sgml-indent-or-tab)
  (insert "\n")
  (sgml-indent-or-tab)
  (setq insert (point))
  (insert "\n</service>")
  (sgml-indent-or-tab)
  (goto-char insert))
(define-abbrev xml-mode-abbrev-table "'l" "" 'cursus-make-lauds)

(defun cursus-make-prime ()
  ""
  (interactive)
  (if
   (confirm "Add marker for Hours?")
   (progn
     (beginning-of-line)
     (insert "<!--\n***   Hours\n -->\n")))
  (insert "<service name=\"prime\">")
  (if (y-or-n-p "Insert rubric?")
      (insert "<rubric type=\"serviceTitle\"> Ad primam &punctus;</rubric>"))
  (sgml-indent-or-tab)
  (insert "\n")
  (sgml-indent-or-tab)
  (setq insert (point))
  (insert "\n</service>")
  (sgml-indent-or-tab)
  (goto-char insert))
(define-abbrev xml-mode-abbrev-table "'1" "" 'cursus-make-prime)

(defun cursus-make-terce ()
  ""
  (interactive)
  (insert "<service name=\"terce\">")
  (if (y-or-n-p "Insert rubric?")
      (insert "<rubric type=\"serviceTitle\"> Ad tertiam &punctus;</rubric>"))
  (sgml-indent-or-tab)
  (insert "\n")
  (sgml-indent-or-tab)
  (setq insert (point))
  (insert "\n</service>")
  (sgml-indent-or-tab)
  (goto-char insert))
(define-abbrev xml-mode-abbrev-table "'3" "" 'cursus-make-terce)

(defun cursus-make-sext ()
  ""
  (interactive)
  (insert "<service name=\"sext\">")
  (if (y-or-n-p "Insert rubric?")
      (insert "<rubric type=\"serviceTitle\"> Ad sextam &punctus;</rubric>"))
  (sgml-indent-or-tab)
  (insert "\n")
  (sgml-indent-or-tab)
  (setq insert (point))
  (insert "\n</service>")
  (sgml-indent-or-tab)
  (goto-char insert))
(define-abbrev xml-mode-abbrev-table "'6" "" 'cursus-make-sext)

(defun cursus-make-nones ()
  ""
  (interactive)
  (insert "<service name=\"nones\">")
  (if (y-or-n-p "Insert rubric?")
      (insert "<rubric type=\"serviceTitle\"> Ad nonam &punctus;</rubric>"))
  (sgml-indent-or-tab)
  (insert "\n")
  (sgml-indent-or-tab)
  (setq insert (point))
  (insert "\n</service>")
  (sgml-indent-or-tab)
  (goto-char insert))
(define-abbrev xml-mode-abbrev-table "'9" "" 'cursus-make-nones)

(defun cursus-make-vesp2 ()
  ""
  (interactive)
  (insert "<service name=\"vesp2\">")
  (if (y-or-n-p "Insert rubric?")
      (insert "<rubric type=\"serviceTitle\"> Ad vesperas&punctus;</rubric>"))
  (sgml-indent-or-tab)
  (insert "\n")
  (sgml-indent-or-tab)
  (setq insert (point))
  (insert "\n</service>")
  (sgml-indent-or-tab)
  (goto-char insert))
(define-abbrev xml-mode-abbrev-table "'v2" "" 'cursus-make-vesp2)

;;}}} ---------------------------------------------------------------------------

;;{{{ Miscellaneous small functions:

(defun cursus-make-ed-note ()
  (interactive)
  (insert "<note type=\"editorial\" resp=\""user-initials"\">")
  (setq ret (point))
  (insert "</note>")
  (goto-char ret))
(define-abbrev xml-mode-abbrev-table "'ednote" "" 'cursus-make-ed-note)

(defun cursus-make-gen-rubric ()
  (interactive)
  (insert "<rubric type=\"general\">")
  (setq ret (point))
  (insert "</rubric>")
  (goto-char ret))
(define-abbrev xml-mode-abbrev-table "'rgen" "" 'cursus-make-gen-rubric)


;;}}} ---------------------------------------------------------------------------

;;{{{ Keybindings:

(add-hook 'xml-mode-hook
	  '(lambda ()
;;;;; entities:
            (define-key xml-mode-map "\C-cc;"
              'cursus-punctel-entity)
            (define-key xml-mode-map "\C-cc:"
              'cursus-colon-entity)
            (define-key xml-mode-map "\C-cc/"
              'cursus-virgule-entity)
            (define-key xml-mode-map "\C-cc."
              'cursus-punctus-entity)
            (define-key xml-mode-map "\C-ccq"
              'cursus-etrel-entity)
            (define-key xml-mode-map "\C-cc&"
              'cursus-etc-entity)
            (define-key xml-mode-map "\C-cc'"
              'cursus-hook-entity)
            (define-key xml-mode-map "\C-ccv"
              'cursus-verse-entity)
            (define-key xml-mode-map "\C-cce"
              'cursus-evovae-entity)
            (define-key xml-mode-map "\C-cc-"
              'cursus-bar-entity)
            (define-key xml-mode-map "\C-ccp"
              'cursus-para-entity)
;;;;; other functions:
            (define-key xml-mode-map "\C-ccm"
              'tempo-template-mkup-mus)
;;             (define-key xml-mode-map "\C-cc\C-f"
;;               'cursus-fetch-cao-item)
            (define-key xml-mode-map "\C-cc\C-e"
              'cursus-edit-repos)
            (define-key xml-mode-map "\C-cc\C-c"
              'cursus-wit-test)
            (define-key xml-mode-map "\C-cc\C-i"
              'cursus-insert-id-number)
            (define-key xml-mode-map "\C-cc\C-n"
              'cursus-make-new-milestone)
            (define-key xml-mode-map "\C-cc\C-d"
              'cursus-clean-app-wits)
            (define-key xml-mode-map "\C-cc\C-k"
              'cursus-insert-vbody-crossref)
            (define-key xml-mode-map (kbd "C-c c x")
              'cursus-add-ms-to-current-wits)
            (define-key xml-mode-map "\C-ccf"
              'cursus-make-new-feria-tag)
            (define-key xml-mode-map (kbd "C-c c h")
              'my-capital-markup)
            (define-key xml-mode-map "\C-ccs"
              'cursus-insert-silent-attrib)
            (define-key xml-mode-map (kbd "C-c c M-p")
              'cursus-find-place)
            (define-key xml-mode-map (kbd "C-c c M-d")
              'cursus-find-day)
            (define-key xml-mode-map (kbd "C-c c M-u")
              'cursus-translate-daycode)
            (define-key xml-mode-map (kbd "C-c c M-c")
              'cursus-find-daycode)
            (define-key xml-mode-map (kbd "C-c c M-r")
              'cursus-find-repos-item)
;;;;; replacements for psgml standards:
            (define-key xml-mode-map (kbd "C-c <right>")
              'sgml-end-of-element)
            (define-key xml-mode-map (kbd "C-c <left>")
              'sgml-beginning-of-element)
            ))

;;}}} ---------------------------------------------------------------------------

;;{{{ Cursus menu

;; (easy-menu-define 
;;     my-cursus-editing-functions-menu xml-mode-map "CURSUS menu"
;;   '("CURSUS"
;;     ["Add new reading to repository item"  cursus-edit-repos      t]
;;     ["Fetch CAO item by serial number"     cursus-fetch-cao-item  t]
;;     ["Add CAO wits as attribute"           cursus-add-cao-wits    t]
;;     ["Make wit=\"CAO\" into full set"      cursus-make-cao-full   t]

;; (easy-menu-define
;;  my-cursus-templates-menu xml-mode-map "Templates menu"
;;  '("Templates"
;;    ("CURSUS templates"
;;     ("For Repository"
;;      ["Antiphon"                tempo-template-rep-ant           t]
;;      ["Responsory"              tempo-template-rep-resp          t]
;;      ["Prayer"                  tempo-template-rep-prayer        t] 
;;      )
;;     "--"
;;     ("For MS Files"
;;      ("Items"
;;     ["Antiphon (no music)"          tempo-template-ant               t]
;;     ["Antiphon (+ music)"           tempo-template-mus-ant           t]
;;     ["Gospel Antiphon (no music)"   tempo-template-eant              t]
;;     ["Gospel Antiphon (+ music)"    tempo-template-mus-eant          t]
;;     ["Responsory (no music)"        tempo-template-resp              t]
;;     ["Responsory (+ music)"         tempo-template-mus-resp          t]
;;     ["Prayer"                       tempo-template-prayer            t]
;;     ["Lection ('lect)"              tempo-template-lection           t]
;;     )
;;      "---"
;;      ("Incipits"
;;       ["Antiphon ('iant)"           tempo-template-incipit-ant       t]
;;       ["Gospel Antiphon ('ieant)"   tempo-template-incipit-eant      t]
;;       ["Canticum ('icant)"          tempo-template-incipit-cant      t]
;;       ["Capitulum ('ichap)"         tempo-template-incipit-chapter   t]
;;       ["Gospel ('igosp)"            tempo-template-incipit-gospel    t]
;;       ["Hymn ('ihymn)"              tempo-template-incipit-hymn      t]
;;       ["Invitatory ('iinv)"         tempo-template-incipit-invit     t]
;;       ["Prayer ('ior)"              tempo-template-incipit-prayer    t]
;;       ["Psalm ('ips)"               tempo-template-incipit-psalm     t]
;;       ["Respond ('iresp)"           tempo-template-incipit-respond   t]
;;       ["Versicle ('iversl)"         tempo-template-incipit-versicle  t]
;;       )
;;     "--"
;;     ("Rubrics"
;;      ["Canticum"                    tempo-template-rubric-cant       t]
;;      ["dayTitle"                    tempo-template-rubric-day        t]
;;      ["feriaTitle"                  tempo-template-rubric-feria      t]
;;      ["Gospel"                      tempo-template-rubric-gospel     t]
;;      ["Lection"                     tempo-template-rubric-lection    t]
;;      ["nocturnTitle"                tempo-template-rubric-nocturn    t]
;;      ["serviceTitle"                tempo-template-rubric-service    t]
;;      ["General rubric"              tempo-template-rubric-levis      t]
;;      )
;;     "---"
;;     ("Series"
;;      ["Nocturn of Matins (no music)"tempo-template-noct              t]
;;      ["Nocturn of Matins (+ music)" tempo-template-mus-noct          t]
;;      ["Lauds (no music)"            tempo-template-lauds             t]
;;      ["Lauds (+ music)"             tempo-template-mus-lauds         t]
;;      ["Hours (full set: no music)"  tempo-template-hours             t]
;;      ["Hours (full set + music)"    tempo-template-mus-hours         t]
;;      )
;;     )
;;     "--"
;;     ("Add markup"                                
;;      ["Music (to region)"           tempo-template-mkup-mus          t]
;;      ["Capital letter"              my-capital-markup                t]
;;      )
;;     ("Insert Outline Markers"
;;      ["Level 1 (Season: 'lvl1)"     tempo-template-cursus-level-one  t]
;;      ["Level 2 (Day: 'lvl2)"        tempo-template-cursus-level-two  t]
;;      ["Level 3 (Service: 'lvl3)"    tempo-template-cursus-level-three t]
;;      ["Level 4 (Subservice: 'lvl4)" tempo-template-cursus-level-four t]
;;      )
;;     ("Insert Folding Markers"
;;      ["Complete fold ('fld)"        tempo-template-ml-fold           t]
;;      ["Opening marker"              tempo-template-ml-fold-begin     t]
;;      ["Closing marker"              tempo-template-ml-fold-end       t]
;;      )
;;     )


;;}}} ---------------------------------------------------------------------------